@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.28 22:00:00                  #
 # ================================================== #
 
 import copy
@@ -14,12 +14,14 @@ import datetime
 import os
 import re
 from pathlib import Path
+from packaging.version import Version
 
-from pygpt_net.provider.config.json_file import JsonFileProvider
+from pygpt_net.provider.core.config.json_file import JsonFileProvider
 
 
 class Config:
     CONFIG_DIR = 'pygpt-net'
+    SNAP_NAME = 'pygpt'
     TYPE_STR = 0
     TYPE_INT = 1
     TYPE_FLOAT = 2
@@ -32,7 +34,6 @@ class Config:
         :param window: Window instance
         """
         self.window = window
-        
         self.path = str(Path(os.path.join(Path.home(), '.config', self.CONFIG_DIR)))
         self.initialized = False
         self.initialized_base = False
@@ -40,12 +41,30 @@ class Config:
         self.data = {}
         self.data_base = {}
         self.version = self.get_version()
-
+        self.dirs = {
+            "capture": "capture",
+            "css": "css",
+            "data": "data",
+            "history": "history",
+            "idx": "idx",
+            "img": "img",
+            "locale": "locale",
+            "presets": "presets",
+            "upload": "upload",
+        }
         self.provider = JsonFileProvider(window)
         self.provider.path = self.get_user_path()
         self.provider.path_app = self.get_app_path()
         self.provider.meta = self.append_meta()
 
+    def is_compiled(self) -> bool:
+        """
+        Return True if compiled version
+
+        :return: True if compiled version
+        """
+        return __file__.endswith('.pyc')
+
     def install(self):
         """Install database and provider data"""
         # install database
@@ -55,9 +74,37 @@ class Config:
         # install provider configs
         self.provider.install()
 
-    def patch(self, app_version):
-        """Patch provider data"""
-        self.provider.patch(app_version)
+    def patch(self, app_version: Version) -> bool:
+        """
+        Patch provider data
+
+        :param app_version: app version
+        :return: True if patched
+        """
+        return self.provider.patch(app_version)
+
+    def get_user_dir(self, dir: str) -> str:
+        """
+        Return user dir
+
+        :param dir: dir name
+        :return: user dir
+        """
+        if dir not in self.dirs:
+            raise Exception('Unknown dir: {}'.format(dir))
+
+        dir_data_allowed = ["img", "capture", "upload"]
+
+        if self.has("upload.data_dir") \
+                and self.get("upload.data_dir") \
+                and dir in dir_data_allowed:
+            path = os.path.join(self.get_user_path(), self.dirs["data"], self.dirs[dir])
+        else:
+            path = os.path.join(self.get_user_path(), self.dirs[dir])
+        if not os.path.exists(path):
+            os.makedirs(path, exist_ok=True)
+
+        return path
 
     def get_app_path(self) -> str:
         """
@@ -65,17 +112,16 @@ class Config:
 
         :return: app root path
         """
-        if __file__.endswith('.pyc'):  # if compiled with pyinstaller
+        if self.is_compiled():  # if compiled with pyinstaller
             return os.path.abspath('.')
         else:
             return os.path.abspath(os.path.dirname(__file__))
 
-    def get_user_path(self):
+    def get_user_path(self) -> str:
         """
-        Return user home path
+        Return user home path (workdir)
 
         :return: user home path
-        :rtype: str
         """
         return self.path
 
@@ -133,23 +179,43 @@ class Config:
         """
         return self.provider.get_options()
 
-    def get(self, key: str) -> any:
+    def get_sections(self) -> dict:
+        """
+        Return settings sections
+
+        :return: settings sections
+        """
+        return self.provider.get_sections()
+
+    def get(self, key: str, default: any = None) -> any:
         """
         Return config value by key
 
         :param key: key
+        :param default: default value
         :return: value
         """
         if key in self.data:
             return self.data[key]
-        return None
+        return default
+
+    def get_lang(self) -> str:
+        """
+        Return language code
+
+        :return: language code
+        """
+        test_lang = os.environ.get('TEST_LANGUAGE')  # if pytest
+        if test_lang:
+            return test_lang
+        return self.get('lang', 'en')
 
     def set(self, key: str, value: any):
         """
         Set config value
 
-        :param key:
-        :param value:
+        :param key: key
+        :param value: value
         """
         self.data[key] = value
 
@@ -261,6 +327,28 @@ class Config:
             self.load_base_config()
         self.data = copy.deepcopy(self.data_base)
 
+    def get_last_used_dir(self) -> str:
+        """
+        Return last used directory
+
+        :return: last used directory
+        """
+        last_dir = self.get_user_dir('data')
+        if self.has("dialog.last_dir"):
+            tmp_dir = self.get("dialog.last_dir")
+            if os.path.isdir(tmp_dir):
+                last_dir = tmp_dir
+        return last_dir
+
+    def set_last_used_dir(self, path: str):
+        """
+        Save last used directory
+
+        :param path: path
+        """
+        self.set('dialog.last_dir', path)
+        self.save()
+
     def get_base(self, option: str = None) -> any:
         """
         Return base config option or all base config
