@@ -6,13 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.11 09:00:00                  #
+# Updated Date: 2024.01.23 21:00:00                  #
 # ================================================== #
 
 from pygpt_net.config import Config
 from pygpt_net.core.assistants import Assistants
 from pygpt_net.core.attachments import Attachments
 from pygpt_net.core.audio import Audio
+from pygpt_net.core.bridge import Bridge
 from pygpt_net.core.calendar import Calendar
 from pygpt_net.core.camera import Camera
 from pygpt_net.core.chain import Chain
@@ -24,9 +25,9 @@ from pygpt_net.core.dispatcher import Dispatcher
 from pygpt_net.core.idx import Idx
 from pygpt_net.core.installer import Installer
 from pygpt_net.core.filesystem import Filesystem
-from pygpt_net.core.gpt import Gpt
 from pygpt_net.core.history import History
 from pygpt_net.core.image import Image
+from pygpt_net.core.llm import LLM
 from pygpt_net.core.models import Models
 from pygpt_net.core.modes import Modes
 from pygpt_net.core.notepad import Notepad
@@ -37,6 +38,7 @@ from pygpt_net.core.prompt import Prompt
 from pygpt_net.core.settings import Settings
 from pygpt_net.core.tokens import Tokens
 from pygpt_net.core.updater import Updater
+from pygpt_net.provider.gpt import Gpt
 
 
 class Container:
@@ -48,10 +50,11 @@ class Container:
         """
         self.window = window
 
-        # core services
+        # core
         self.assistants = Assistants(window)
         self.attachments = Attachments(window)
         self.audio = Audio(window)
+        self.bridge = Bridge(window)
         self.calendar = Calendar(window)
         self.camera = Camera(window)
         self.chain = Chain(window)
@@ -66,6 +69,7 @@ class Container:
         self.history = History(window)
         self.idx = Idx(window)
         self.image = Image(window)
+        self.llm = LLM(window)
         self.installer = Installer(window)
         self.models = Models(window)
         self.modes = Modes(window)
