@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.30 20:00:00                  #
 # ================================================== #
 
 import webbrowser
@@ -54,6 +54,7 @@ class Assistant:
         self.window.ui.toolbox.assistants.update(items)
 
     def prepare(self):
+        """Prepare assistants"""
         # create or get current thread, it is required before conversation start
         if self.window.core.config.get('assistant_thread') is None:
             try:
@@ -92,7 +93,10 @@ class Assistant:
         # update attachments list with list of attachments from assistant
         mode = self.window.core.config.get('mode')
         assistant = self.window.core.assistants.get_by_id(id)
-        self.window.controller.attachment.import_from_assistant(mode, assistant)
+        self.window.controller.attachment.import_from_assistant(
+            mode,
+            assistant,
+        )
         self.window.controller.attachment.update()
         self.update(False)
 
@@ -107,6 +111,7 @@ class Assistant:
                     self.window.controller.model.update_list()
                     self.window.controller.model.select_current()
                     self.window.ui.nodes['preset.prompt'].setPlainText(assistant.instructions)
+                    self.window.controller.presets.from_global()
                     self.refresh()
 
         self.window.controller.ctx.update_ctx()  # update current ctx info
@@ -127,6 +132,8 @@ class Assistant:
             idx = list(items.keys()).index(assistant_id)
             current = self.window.ui.models['assistants'].index(idx, 0)
             self.window.ui.nodes['assistants'].setCurrentIndex(current)
+            self.window.core.config.set('prompt', items[assistant_id].instructions)
+            self.window.ui.nodes['preset.prompt'].setPlainText(items[assistant_id].instructions)
 
     def select_default(self):
         """Set default assistant"""
@@ -134,7 +141,10 @@ class Assistant:
         if assistant is None or assistant == "":
             mode = self.window.core.config.get('mode')
             if mode == 'assistant':
-                self.window.core.config.set('assistant', self.window.core.assistants.get_default_assistant())
+                self.window.core.config.set(
+                    'assistant',
+                    self.window.core.assistants.get_default_assistant(),
+                )
                 self.update()
 
     def create(self) -> AssistantItem:
@@ -167,8 +177,11 @@ class Assistant:
         :param force: if true, imports without confirmation
         """
         if not force:
-            self.window.ui.dialogs.confirm('assistant_import', '',
-                                           trans('confirm.assistant.import'))
+            self.window.ui.dialogs.confirm(
+                'assistant_import',
+                '',
+                trans('confirm.assistant.import'),
+            )
             return
 
         try:
@@ -199,8 +212,11 @@ class Assistant:
         id = self.window.core.config.get('assistant')
 
         if not force:
-            self.window.ui.dialogs.confirm('assistant_clear', '',
-                                           trans('confirm.assistant.clear'))
+            self.window.ui.dialogs.confirm(
+                'assistant_clear',
+                '',
+                trans('confirm.assistant.clear'),
+            )
             return
 
         if id is not None and id != "":
@@ -224,8 +240,11 @@ class Assistant:
                 if self.window.core.assistants.has(id):
                     # if exists then show confirmation dialog
                     if not force:
-                        self.window.ui.dialogs.confirm('assistant_delete', idx,
-                                                       trans('confirm.assistant.delete'))
+                        self.window.ui.dialogs.confirm(
+                            'assistant_delete',
+                            idx,
+                            trans('confirm.assistant.delete'),
+                        )
                         return
 
                     # clear if this is current assistant
