@@ -6,10 +6,9 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.30 20:00:00                  #
 # ================================================== #
 
-import json
 import time
 
 from PySide6.QtCore import QObject, Signal, Slot, QRunnable
@@ -29,12 +28,11 @@ class Threads:
         self.started = False
         self.stop = False
 
-    def create_thread(self):
+    def create_thread(self) -> str:
         """
         Create assistant thread
 
         :return: thread id
-        :rtype: str
         """
         thread_id = self.window.core.gpt.assistants.thread_create()
         self.window.core.config.set('assistant_thread', thread_id)
@@ -53,7 +51,8 @@ class Threads:
                 ctx.set_output(msg.content[0].text.value)
                 paths = self.window.controller.assistant.files.handle_received(ctx, msg)
                 if paths:
-                    ctx.files = list(paths)  # append files paths list to ctx
+                    # append local downloaded files paths list to ctx
+                    ctx.files = self.window.core.filesystem.make_local_list(list(paths))
 
                 # update ctx
                 self.window.core.ctx.update_item(ctx)
@@ -64,6 +63,9 @@ class Threads:
                 # update ctx
                 self.window.core.ctx.update_item(ctx)
 
+                # index ctx (llama-index)
+                self.window.controller.idx.on_ctx_end(ctx)
+
                 # update ctx list
                 self.window.controller.ctx.update()
                 break
@@ -84,6 +86,8 @@ class Threads:
         worker.signals.destroyed.connect(self.handle_destroy)
         worker.signals.started.connect(self.handle_started)
 
+        self.window.stateChanged.emit(self.window.STATE_BUSY)
+
         # start
         self.window.threadpool.start(worker)
         self.started = True
@@ -103,10 +107,12 @@ class Threads:
             self.stop = False
             self.handle_messages(ctx)
             self.window.statusChanged.emit(trans('assistant.run.completed'))
+            self.window.stateChanged.emit(self.window.STATE_IDLE)
         elif status == "failed":
             self.stop = False
             self.window.controller.chat.common.unlock_input()
             self.window.statusChanged.emit(trans('assistant.run.failed'))
+            self.window.stateChanged.emit(self.window.STATE_ERROR)
 
     @Slot()
     def handle_destroy(self):
@@ -153,7 +159,10 @@ class RunWorker(QRunnable):
             while self.check \
                     and not self.window.is_closing \
                     and not self.window.controller.assistant.threads.stop:
-                status = self.window.core.gpt.assistants.run_status(self.ctx.thread, self.ctx.run_id)
+                status = self.window.core.gpt.assistants.run_status(
+                    self.ctx.thread,
+                    self.ctx.run_id,
+                )
                 self.signals.updated.emit(status, self.ctx)
                 # finished or failed
                 if status in self.stop_reasons:
