@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.23 19:00:00                  #
 # ================================================== #
 
 import datetime
@@ -75,6 +75,7 @@ class Camera:
         # signals
         worker.signals.capture.connect(self.handle_capture)
         worker.signals.finished.connect(self.handle_stop)
+        worker.signals.unfinished.connect(self.handle_unfinished)
         worker.signals.stopped.connect(self.handle_stop)
         worker.signals.error.connect(self.handle_error)
 
@@ -115,6 +116,15 @@ class Camera:
         self.thread_started = False
         self.hide_camera(False)
 
+    @Slot()
+    def handle_unfinished(self):
+        """On capture unfinished (never started) signal"""
+        if self.window.core.platforms.is_snap():
+            self.window.ui.dialogs.alert("Camera not opened!\nDid you connect the camera with:\n\n"
+                                         "sudo snap connect pygpt:camera ?")
+        self.thread_started = False
+        self.disable_capture()
+
     def update(self):
         """Update camera frame"""
         if not self.thread_started \
@@ -131,9 +141,13 @@ class Camera:
                                       Qt.KeepAspectRatio, Qt.SmoothTransformation)
         self.window.ui.nodes['video.preview'].video.setPixmap(scaled_pixmap)
 
-    def manual_capture(self):
-        """Capture frame via click on video output"""
-        if not self.is_auto():
+    def manual_capture(self, force: bool = False):
+        """
+        Capture frame via click on video output
+
+        :param force: force capture even if auto is enabled
+        """
+        if not self.is_auto() or force:
             if not self.capture_frame(True):
                 self.window.statusChanged.emit(trans("vision.capture.manual.captured.error"))
         else:
@@ -165,12 +179,12 @@ class Camera:
             now = datetime.datetime.now()
             dt = now.strftime("%Y-%m-%d_%H-%M-%S")
             name = 'cap-' + dt
-            path = os.path.join(self.window.core.config.path, 'capture', name + '.jpg')
+            path = os.path.join(self.window.core.config.get_user_dir('capture'), name + '.jpg')
 
             # capture frame
             compression_params = [cv2.IMWRITE_JPEG_QUALITY, int(self.window.core.config.get('vision.capture.quality'))]
             frame = self.get_current_frame()
-            self.window.controller.drawing.from_camera()  # capture to draw
+            self.window.controller.painter.capture.camera()  # capture to draw
 
             cv2.imwrite(path, frame, compression_params)
             mode = self.window.core.config.get('mode')
@@ -207,7 +221,7 @@ class Camera:
         """
         Hide camera
 
-        :param stop: true if stop capture thread
+        :param stop: True if stop capture thread
         """
         self.window.ui.nodes['video.preview'].setVisible(False)
 
@@ -218,7 +232,7 @@ class Camera:
         """Enable capture"""
         if self.window.core.config.get('mode') != 'vision' \
                 and not self.window.controller.plugins.is_type_enabled('vision')\
-                and not self.window.controller.drawing.is_drawing():
+                and not self.window.controller.painter.is_active():
             return
 
         self.is_capture = True
@@ -232,12 +246,13 @@ class Camera:
         """Disable capture"""
         if self.window.core.config.get('mode') != 'vision' \
                 and not self.window.controller.plugins.is_type_enabled('vision')\
-                and not self.window.controller.drawing.is_drawing():
+                and not self.window.controller.painter.is_active():
             return
 
         self.is_capture = False
         self.window.core.config.set('vision.capture.enabled', False)
         self.window.controller.config.checkbox.apply('config', 'vision.capture.enabled', {'value': False})
+        self.window.ui.nodes['vision.capture.enable'].setChecked(False)
         self.window.ui.nodes['video.preview'].setVisible(False)
         self.stop_capture()
         self.blank_screen()
@@ -259,7 +274,7 @@ class Camera:
         """Enable capture"""
         if self.window.core.config.data['mode'] != 'vision' \
                 and not self.window.controller.plugins.is_type_enabled('vision')\
-                and not self.window.controller.drawing.is_drawing():
+                and not self.window.controller.painter.is_active():
             return
 
         self.auto = True
@@ -275,7 +290,7 @@ class Camera:
         """Disable capture"""
         if self.window.core.config.get('mode') != 'vision' \
                 and not self.window.controller.plugins.is_type_enabled('vision')\
-                and not self.window.controller.drawing.is_drawing():
+                and not self.window.controller.painter.is_active():
             return
 
         self.auto = False
