@@ -6,25 +6,21 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.06 22:00:00                  #
+# Updated Date: 2024.01.29 16:00:00                  #
 # ================================================== #
 
 import json
 
-from PySide6.QtCore import QObject, Signal
+from PySide6.QtCore import Signal
 
 from pygpt_net.core.dispatcher import Event
-from pygpt_net.core.worker import Worker
-
-
-class WorkerSignals(QObject):
-    finished = Signal(object)
+from pygpt_net.core.worker import Worker, WorkerSignals
 
 
 class Command:
     def __init__(self, window=None):
         """
-        Command  controller
+        Commands dispatch controller
 
         :param window: Window instance
         """
@@ -37,33 +33,32 @@ class Command:
 
         :param event: event object
         """
-        self.dispatch_sync(event)
-        # self.dispatch_async(event)  # TODO: async execution
+        self.window.core.debug.info("Dispatch CMD event begin: " + event.name)
+        if self.window.core.debug.enabled():
+            self.window.core.debug.debug("EVENT BEFORE: " + str(event))
 
-    def dispatch_sync(self, event: Event):
-        """
-        Dispatch cmd event (command execution)
-
-        :param event: event object
-        """
         for id in self.window.core.plugins.get_ids():
             if self.window.controller.plugins.is_enabled(id):
-                if event.stop or (event.name == "cmd.execute" and self.is_stop()):
+                if event.stop or (event.name == Event.CMD_EXECUTE and self.is_stop()):
                     if self.is_stop():
                         self.stop = False  # unlock needed here
                     break
-                self.window.core.dispatcher.apply(id, event, is_async=False)
+                if self.window.core.debug.enabled():
+                    self.window.core.debug.debug("Apply [{}] to plugin: ".format(event.name) + id)
+
+                self.window.stateChanged.emit(self.window.STATE_BUSY)
+                self.window.core.dispatcher.apply(id, event)
 
         # WARNING: do not emit finished signal here if event is internal (otherwise it will be emitted twice)
         # it is handled already in internal event, in synchronous way
         if event.ctx is not None and event.ctx.internal:
             return
 
-        self.handle_finished(event)  # emit finished signal only for non-internal events
+        self.handle_finished(event)  # emit finished signal only for non-internal (user-called) events
 
     def dispatch_async(self, event: Event):
         """
-        Dispatch cmd event (command execution)
+        Dispatch async cmd event (command execution)
 
         :param event: event object
         """
@@ -85,38 +80,45 @@ class Command:
         """
         for id in window.core.plugins.get_ids():
             if window.controller.plugins.is_enabled(id):
-                if event.stop or (event.name == "cmd.execute" and self.is_stop()):
+                if event.stop or (event.name == Event.CMD_EXECUTE and self.is_stop()):
                     if self.is_stop():
                         self.stop = False  # unlock needed here
                     break
                 window.core.dispatcher.apply(id, event, is_async=True)
         finished_signal.emit(event)
 
-    def is_stop(self):
+    def is_stop(self) -> bool:
         """
         Check if stop is requested
 
         :return: True if stop is requested
-        :rtype: bool
         """
         return self.stop
 
-    def handle_debug(self, data):
+    def handle_debug(self, data: any):
         """
         Handle thread debug log
 
-        :param data
+        :param data to log
         """
-        self.window.controller.debug.log(str(data))
+        self.window.core.debug.info(data)
 
     def handle_finished(self, event: Event):
         """
-        Handle thread command execution finish
+        Handle command execution finish (response from sync execution)
 
         :param event: event object
         """
         ctx = event.ctx
-        self.window.ui.status("")  # Clear status
-        if ctx.reply:
-            self.window.controller.chat.input.send(json.dumps(ctx.results), force=True, internal=ctx.internal)
+        if ctx is not None:
+            self.window.core.debug.info("Reply...")
+            if self.window.core.debug.enabled():
+                self.window.core.debug.debug("CTX REPLY: " + str(ctx))
 
+            self.window.ui.status("")  # Clear status
+            if ctx.reply:
+                self.window.controller.chat.input.send(
+                    json.dumps(ctx.results),
+                    force=True,
+                    internal=ctx.internal,
+                )
