@@ -6,11 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.27 17:00:00                  #
 # ================================================== #
 
 from datetime import datetime
 
+from PySide6.QtCore import Slot
 from PySide6.QtGui import QTextCursor
 
 
@@ -22,7 +23,7 @@ class Debug:
         :param window: Window instance
         """
         self.window = window
-        self.is_logger = False
+        self.is_logger = False  # logger window opened
 
     def update(self):
         """Update debug"""
@@ -54,12 +55,21 @@ class Debug:
                 if all or id not in not_realtime:
                     self.window.controller.dialogs.debug.update_worker(id)
 
-    def log(self, data, window: bool = True):
+    @Slot(object)
+    def handle_log(self, data: any):
         """
-        Log text
+        Handle log message
+
+        :param data: message to log
+        """
+        self.log(data)
+
+    def log(self, data: any, window: bool = True):
+        """
+        Log message to console or logger window
 
         :param data: text to log
-        :param window: true if log to all plugins (enabled or not)
+        :param window: True if log to window, False if log to console
         """
         if not window:
             print(str(data))
@@ -68,20 +78,28 @@ class Debug:
         if not self.is_logger or data is None or data.strip() == '':
             return
 
-        # prepend log with timestamp
-        data = datetime.now().strftime('%H:%M:%S') + ': ' + str(data)
-        # append log to logger
-        txt = self.window.logger.toPlainText()
-        if txt.strip() != '':
-            txt += '\n'
-        txt += data
-        self.window.logger.setPlainText(txt)
-        # set cursor to end
-        self.window.logger.moveCursor(QTextCursor.End)
+        data = datetime.now().strftime('%H:%M:%S.%f') + ': ' + str(data)
+        cur = self.window.logger.textCursor()  # Move cursor to end of text
+        cur.movePosition(QTextCursor.End)
+        s = str(data) + "\n"
+        while s:
+            head, sep, s = s.partition("\n")  # Split line at LF
+            cur.insertText(head)  # Insert text at cursor
+            if sep:  # New line if LF
+                cur.insertText("\n")
+        self.window.logger.setTextCursor(cur)  # Update visible cursor
+
+    def logger_enabled(self) -> bool:
+        """
+        Check if debug window is enabled
+
+        :return: True if enabled, False otherwise
+        """
+        return self.is_logger
 
     def open_logger(self):
         """Open logger dialog"""
-        self.window.ui.dialogs.open('logger')
+        self.window.ui.dialogs.open('logger', width=800, height=600)
         self.is_logger = True
         self.update()
 
