@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.30 20:00:00                  #
 # ================================================== #
 
 
@@ -19,7 +19,7 @@ class Layout:
         """
         self.window = window
         # self.splitters = ["main", "main.output", "toolbox", "toolbox.mode", "toolbox.presets"]
-        self.splitters = ["main", "main.output", "toolbox", "toolbox.mode", "calendar"]  # prevent assistants column disappearing
+        self.splitters = ["main", "main.output", "toolbox", "toolbox.mode", "calendar"]
         self.text_nodes = ["input"]
 
     def setup(self):
@@ -36,9 +36,16 @@ class Layout:
         self.scroll_restore()
 
         # restore plugin settings state
-        self.window.controller.plugins.set_by_tab(self.window.ui.tabs['plugin.settings'].currentIndex())
+        self.window.controller.plugins.set_by_tab(
+            self.window.ui.tabs['plugin.settings'].currentIndex()
+        )
         self.window.controller.ui.update_tokens()  # update tokens
 
+        # minimize window after startup
+        if self.window.core.config.has('layout.minimized') \
+                and self.window.core.config.get('layout.minimized'):
+            self.window.showMinimized()
+
     def save(self):
         """Save layout state"""
         self.text_nodes_save()
@@ -99,6 +106,9 @@ class Layout:
         """Save splitters state"""
         data = {}
         for splitter in self.splitters:
+            # do not save main splitter state if notepad was not opened yet
+            if splitter == "calendar" and not self.window.controller.notepad.opened_once:
+                continue
             data[splitter] = self.window.ui.splitters[splitter].sizes()
         self.window.core.config.set('layout.splitters', data)
 
@@ -135,7 +145,7 @@ class Layout:
         # notepads
         for id in self.window.ui.notepad:
             scroll_id = "notepad." + str(id)
-            data[scroll_id] = self.window.ui.notepad[id].verticalScrollBar().value()
+            data[scroll_id] = self.window.ui.notepad[id].textarea.verticalScrollBar().value()
         self.window.core.config.set('layout.scroll', data)
 
     def scroll_restore(self):
@@ -149,7 +159,7 @@ class Layout:
                 id = int(scroll_id.replace("notepad.", ""))
                 if id in self.window.ui.notepad:
                     try:
-                        self.window.ui.notepad[id].verticalScrollBar().setValue(data[scroll_id])
+                        self.window.ui.notepad[id].textarea.verticalScrollBar().setValue(data[scroll_id])
                     except Exception as e:
                         print("Error while restoring scroll state: " + str(e))
                         self.window.core.debug.log(e)
@@ -170,8 +180,10 @@ class Layout:
                 geometry_data = data['geometry']
                 self.window.move(geometry_data['x'], geometry_data['y'])
                 self.window.resize(geometry_data['width'], geometry_data['height'])
-            if 'maximized' in data and data['maximized']:
-                self.window.showMaximized()
+            if not self.window.core.config.has('layout.minimized') \
+                    or not self.window.core.config.get('layout.minimized'):
+                if 'maximized' in data and data['maximized']:
+                    self.window.showMaximized()
         except Exception as e:
             print("Error while restoring window state: " + str(e))
             self.window.core.debug.log(e)
@@ -201,3 +213,16 @@ class Layout:
                 except Exception as e:
                     print("Error while restoring group state: " + str(e))
                     self.window.core.debug.log(e)
+
+    def restore_settings(self):
+        """Restore groups state"""
+        if not self.window.core.config.has('layout.groups'):
+            return
+        data = self.window.core.config.get('layout.groups')
+        for id in self.window.ui.groups:
+            if id in data and id.startswith('settings.advanced.'):
+                try:
+                    self.window.ui.groups[id].collapse(data[id])
+                except Exception as e:
+                    print("Error while restoring group state: " + str(e))
+                    self.window.core.debug.log(e)
