@@ -6,10 +6,11 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.08 17:00:00                  #
+# Updated Date: 2024.01.30 20:00:00                  #
 # ================================================== #
 
 from pygpt_net.core.dispatcher import Event
+from pygpt_net.item.ctx import CtxItem
 from pygpt_net.utils import trans
 
 
@@ -34,7 +35,7 @@ class Mode:
         mode = self.window.core.modes.get_by_idx(idx)
         self.set(mode)
 
-        event = Event('mode.select', {
+        event = Event(Event.MODE_SELECT, {
             'value': mode,
         })
         self.window.core.dispatcher.dispatch(event)
@@ -49,7 +50,9 @@ class Mode:
         if mode == "assistant":
             if self.window.core.ctx.current is not None \
                     and self.window.core.ctx.assistant is not None:
-                self.window.controller.assistant.select_by_id(self.window.core.ctx.assistant)
+                self.window.controller.assistant.select_by_id(
+                    self.window.core.ctx.assistant
+                )
 
         self.window.core.config.set('mode', mode)
         self.window.core.config.set('model', "")
@@ -61,9 +64,6 @@ class Mode:
         self.window.controller.ui.update()
         self.window.ui.status(trans('status.started'))
 
-        # vision camera
-        self.window.controller.ui.update_vision()
-
         # if assistant mode then update ctx label
         if mode == "assistant":
             self.window.controller.ctx.common.update_label_by_current()
@@ -128,6 +128,23 @@ class Mode:
                 preset.temperature = temperature
                 self.window.core.presets.save(preset_id)
 
+    def switch_inline(self, mode: str, ctx: CtxItem, prompt: str) -> str:
+        """
+        Switch inline mode
+
+        :param mode: current mode
+        :param ctx: ctx item
+        :param prompt: prompt text
+        :return: changed mode
+        """
+        event = Event(Event.MODE_BEFORE, {
+            'value': mode,
+            'prompt': prompt,
+        })
+        event.ctx = ctx
+        self.window.core.dispatcher.dispatch(event)
+        return event.data['value']
+
     def update_mode(self):
         """Update mode"""
         self.select_default()
