@@ -6,13 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.06 04:00:00                  #
+# Updated Date: 2024.01.30 20:00:00                  #
 # ================================================== #
-
-import datetime
+from PySide6.QtGui import QIcon
 
 from pygpt_net.item.notepad import NotepadItem
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
 
 
 class Notepad:
@@ -23,8 +23,9 @@ class Notepad:
         :param window: Window instance
         """
         self.window = window
-        self.default_num_notepads = 3
+        self.default_num_notepads = 1
         self.start_tab_idx = 4  # tab idx from notepad starts
+        self.opened_once = False
 
     def load(self):
         """Load all notepads contents"""
@@ -52,11 +53,35 @@ class Notepad:
 
     def reload_tab_names(self):
         """Reload tab names (after lang change)"""
+        num_notepads = self.get_num_notepads()
         items = self.window.core.notepad.get_all()
+        if num_notepads > 0:
+            for i in range(1, num_notepads + 1):
+                if i not in items or not items[i].initialized:
+                    tab = i + (self.start_tab_idx - 1)
+                    if num_notepads > 1:
+                        self.window.ui.tabs['output'].setTabText(
+                            tab,
+                            trans('output.tab.notepad') + " " + str(i),
+                        )
+                    else:
+                        self.window.ui.tabs['output'].setTabText(
+                            tab,
+                            trans('output.tab.notepad'),
+                        )
+                    self.window.ui.tabs['output'].setTabIcon(
+                        tab,
+                        QIcon(":/icons/paste.svg"),
+                    )
+
         for idx in items:
             title = items[idx].title
             if items[idx].initialized and title is not None and len(title) > 0:
-                self.update_name(idx, items[idx].title, False)
+                self.update_name(
+                    idx,
+                    items[idx].title,
+                    False,
+                )
 
     def get_notepad_name(self, idx: int):
         """
@@ -65,7 +90,11 @@ class Notepad:
         :param idx: notepad idx
         :return: notepad name
         """
-        title = trans('text.context_menu.copy_to.notepad') + ' ' + str(idx)
+        num = self.get_num_notepads()
+        if num > 1:
+            title = trans('text.context_menu.copy_to.notepad') + ' ' + str(idx)
+        else:
+            title = trans('text.context_menu.copy_to.notepad')
         item = self.window.core.notepad.get_by_id(idx)
         if item is None:
             return None
@@ -99,6 +128,7 @@ class Notepad:
         :param name: notepad name
         :param close: close dialog
         """
+        num = self.get_num_notepads()
         item = self.window.core.notepad.get_by_id(idx)
         if item is None:
             item = NotepadItem()
@@ -107,11 +137,25 @@ class Notepad:
 
         tab_idx = idx + (self.start_tab_idx - 1)  # calculate tab idx
         if name is None or len(name) == 0:
-            self.window.ui.tabs['output'].setTabText(tab_idx, trans('output.tab.notepad') + " " + str(idx))
+            # set default name
+            if num > 1:
+                self.window.ui.tabs['output'].setTabText(
+                    tab_idx,
+                    trans('output.tab.notepad') + " " + str(idx),
+                )
+            else:
+                self.window.ui.tabs['output'].setTabText(
+                    tab_idx,
+                    trans('output.tab.notepad'),
+                )
             item.title = ""
             item.initialized = False
         else:
-            self.window.ui.tabs['output'].setTabText(tab_idx, name)
+            # set custom name
+            self.window.ui.tabs['output'].setTabText(
+                tab_idx,
+                name,
+            )
             item.title = name
             item.initialized = True
         self.window.core.notepad.update(item)
@@ -168,8 +212,8 @@ class Notepad:
         dt = ""  # TODO: add to config append date/time
         # dt = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S") + ":\n--------------------------\n"
         prev_text = self.window.ui.notepad[idx].toPlainText()
-        if prev_text != "":
-            prev_text += "\n\n"
+        if prev_text.strip() != "":
+            prev_text += "\n"
         new_text = prev_text + dt + text.strip()
         self.window.ui.notepad[idx].setText(new_text)
         self.save(idx)
@@ -199,6 +243,16 @@ class Notepad:
         self.window.core.notepad.update(item)
         self.update()
 
+    def open(self):
+        """Open notepad"""
+        # if notepad disabled, do nothing
+        if self.get_num_notepads() == 0:
+            return
+        # switch to first notepad tab if current tab is not notepad
+        if self.window.controller.ui.current_tab < self.start_tab_idx:
+            self.window.ui.tabs['output'].setCurrentIndex(self.start_tab_idx)
+        self.window.activateWindow()  # focus
+
     def update(self):
         """Update notepads UI"""
         pass
