@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.07 02:00:00                  #
+# Updated Date: 2024.01.30 17:00:00                  #
 # ================================================== #
 
 from PySide6.QtGui import QAction
@@ -53,20 +53,14 @@ class Plugins:
     def setup_menu(self):
         """Set up plugins menu"""
         for id in self.window.core.plugins.get_ids():
-            plugin = self.window.core.plugins.get(id)
             if id in self.window.ui.menu['plugins']:
                 continue
-            default_name = plugin.name
-            trans_key = 'plugin.' + id
-            name = trans(trans_key)
-            if name == trans_key:
-                name = default_name
-            if plugin.use_locale:
-                domain = 'plugin.{}'.format(id)
-                name = trans('plugin.name', False, domain)
+            name = self.window.core.plugins.get_name(id)
+            tooltip = self.window.core.plugins.get_desc(id)
             self.window.ui.menu['plugins'][id] = QAction(name, self.window, checkable=True)
             self.window.ui.menu['plugins'][id].triggered.connect(
                 lambda checked=None, id=id: self.toggle(id))
+            self.window.ui.menu['plugins'][id].setToolTip(tooltip)
             self.window.ui.menu['menu.plugins'].addAction(self.window.ui.menu['plugins'][id])
 
     def setup_config(self):
@@ -85,8 +79,8 @@ class Plugins:
                 self.window.ui.menu['plugins'][id].setChecked(True)
 
         self.handle_types()
-        self.window.controller.ui.update_active()  # refresh active elements
-        self.window.controller.ui.update_vision()  # vision camera
+        self.window.controller.ui.mode.update()  # refresh active elements
+        self.window.controller.ui.vision.update()  # vision camera
 
     def enable(self, id: str):
         """
@@ -98,8 +92,8 @@ class Plugins:
             self.enabled[id] = True
             self.window.core.plugins.enable(id)
 
-            # dispatch event
-            event = Event('enable', {
+            # dispatch plugin enable event
+            event = Event(Event.ENABLE, {
                 'value': id,
             })
             self.window.core.dispatcher.dispatch(event)
@@ -121,11 +115,11 @@ class Plugins:
             self.enabled[id] = False
             self.window.core.plugins.disable(id)
 
-            # dispatch event
-            event = Event('disable', {
+            # dispatch plugin disable event
+            event = Event(Event.DISABLE, {
                 'value': id,
             })
-            self.window.core.dispatcher.dispatch(event)
+            self.window.core.dispatcher.dispatch(event, all=True)  # dispatch to all plugins, including disabled now
 
             # update audio menu
             if self.has_type(id, 'audio.input') or self.has_type(id, 'audio.output'):
@@ -161,8 +155,8 @@ class Plugins:
 
         self.handle_types()
         self.window.controller.ui.update_tokens()  # refresh tokens
-        self.window.controller.ui.update_active()  # refresh active elements
-        self.window.controller.ui.update_vision()  # vision camera
+        self.window.controller.ui.mode.update()  # refresh active elements
+        self.window.controller.ui.vision.update()  # vision camera
         self.window.controller.attachment.update()  # attachments update
 
     def set_by_tab(self, idx: int):
@@ -211,7 +205,7 @@ class Plugins:
         """Destroy plugins workers"""
 
         # send force stop event
-        event = Event('force.stop', {})
+        event = Event(Event.FORCE_STOP, {})
         self.window.core.dispatcher.dispatch(event)
 
         for id in self.window.core.plugins.get_ids():
@@ -264,8 +258,21 @@ class Plugins:
             elif type == 'schedule':
                 if self.is_type_enabled(type):
                     self.window.ui.plugin_addon['schedule'].setVisible(True)
+                    # get tasks count by throwing "get option" event
+                    num = 0
+                    data = {
+                        'name': 'scheduled_tasks_count',
+                        'value': num,
+                    }
+                    event = Event(Event.PLUGIN_OPTION_GET, data)
+                    self.window.core.dispatcher.dispatch(event)
+                    if 'value' in event.data:
+                        num = event.data['value']
+                    # update tray menu
+                    self.window.ui.tray.update_schedule_tasks(num)
                 else:
                     self.window.ui.plugin_addon['schedule'].setVisible(False)
+                    self.window.ui.tray.hide_schedule_menu()
 
     def on_update(self):
         """Called on update"""
@@ -303,48 +310,55 @@ class Plugins:
         if c > 0:
             count_str = "+ " + str(c) + " " + trans('chatbox.plugins')
         self.window.ui.nodes['chat.plugins'].setText(count_str)
-        self.window.ui.nodes['chat.plugins'].setToolTip(tooltip)  
+        self.window.ui.nodes['chat.plugins'].setToolTip(tooltip)
+
+    def from_commands(self, cmds: list):
+        """
+        Pack commands
+
+        :param cmds: commands list
+        :return parsed commands
+        """
+        commands = []
+        for cmd in cmds:
+            if 'cmd' in cmd:
+                commands.append(cmd)
+        return commands
 
     def apply_cmds(self, ctx: CtxItem, cmds: list):
         """
         Apply commands
 
         :param ctx: CtxItem
-        :param cmds: commands
+        :param cmds: commands list
         """
-        commands = []
-        for cmd in cmds:
-            if 'cmd' in cmd:
-                commands.append(cmd)
+        commands = self.from_commands(cmds)
 
         if len(commands) == 0:
             return
 
-        # dispatch 'cmd.execute' event
-        event = Event('cmd.execute', {
-            'commands': commands
+        # dispatch command execute event
+        event = Event(Event.CMD_EXECUTE, {
+            'commands': commands,
         })
         event.ctx = ctx
         self.window.controller.command.dispatch(event)
 
-    def apply_cmds_only(self, ctx: CtxItem, cmds: list):
+    def apply_cmds_inline(self, ctx: CtxItem, cmds: list):
         """
-        Apply commands
+        Apply inline commands
 
         :param ctx: CtxItem
-        :param cmds: commands
+        :param cmds: commands list
         """
-        commands = []
-        for cmd in cmds:
-            if 'cmd' in cmd:
-                commands.append(cmd)
+        commands = self.from_commands(cmds)
 
         if len(commands) == 0:
             return
 
-        # dispatch 'cmd.only' event
-        event = Event('cmd.only', {
-            'commands': commands
+        # dispatch inline command event
+        event = Event(Event.CMD_INLINE, {
+            'commands': commands,
         })
         event.ctx = ctx
         self.window.controller.command.dispatch(event)
