@@ -6,9 +6,10 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.08 17:00:00                  #
+# Updated Date: 2024.01.19 19:00:00                  #
 # ================================================== #
 
+from pygpt_net.core.dispatcher import Event
 from pygpt_net.utils import trans
 
 
@@ -23,6 +24,8 @@ class Settings:
         self.config_dialog = False
         self.config_initialized = False
         self.current_plugin = None
+        self.width = 800
+        self.height = 500
 
     def setup(self):
         """Set up plugin settings"""
@@ -46,9 +49,14 @@ class Settings:
             self.config_initialized = True
         if not self.config_dialog:
             self.init()
-            self.window.ui.dialogs.open('plugin_settings', width=800, height=500)
+            self.window.ui.dialogs.open('plugin_settings', width=self.width, height=self.height)
             self.config_dialog = True
 
+    def open_plugin(self, id: str):
+        """Open plugin settings dialog"""
+        self.current_plugin = id
+        self.open()
+
     def init(self):
         """Initialize plugin settings options"""
         # select the first plugin on list if no plugin selected yet
@@ -57,7 +65,7 @@ class Settings:
                 self.current_plugin = list(self.window.core.plugins.plugins.keys())[0]
 
         # assign plugins options to config dialog fields
-        for id in self.window.core.plugins.plugins:
+        for id in self.window.core.plugins.plugins.keys():
             plugin = self.window.core.plugins.plugins[id]
             options = plugin.setup()  # get plugin options
 
@@ -68,7 +76,7 @@ class Settings:
 
     def save(self):
         """Save plugin settings"""
-        for id in self.window.core.plugins.plugins:
+        for id in self.window.core.plugins.plugins.keys():
             plugin = self.window.core.plugins.plugins[id]
             options = plugin.setup()  # get plugin options
 
@@ -92,6 +100,10 @@ class Settings:
         self.close()
         self.window.ui.status(trans('info.settings.saved'))
 
+        # dispatch on update event
+        event = Event(Event.PLUGIN_SETTINGS_CHANGED)
+        self.window.core.dispatcher.dispatch(event)
+
     def close(self):
         """Close plugin settings dialog"""
         if self.config_dialog:
@@ -135,7 +147,7 @@ class Settings:
         """
         Get plugin option
 
-        :param id: option id
+        :param id: plugin id
         :param key: option key
         :return: option value
         """
