@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.07 08:00:00                  #
+# Updated Date: 2024.01.12 21:00:00                  #
 # ================================================== #
 
 import os
@@ -24,8 +24,12 @@ class Settings:
         """
         self.window = window
         self.editor = Editor(window)
-        self.width = 500
-        self.height = 600
+        self.width = 800
+        self.height = 500
+
+    def setup(self):
+        """Set up settings editor"""
+        self.editor.setup()
 
     def load(self):
         """Load settings"""
@@ -56,9 +60,27 @@ class Settings:
                 else:
                     self.window.ui.menu['config.' + id].setChecked(False)
 
+    def open_section(self, section: str):
+        """
+        Open settings section
+
+        :param section: section id
+        """
+        id = 'settings'
+        tab = self.get_tab_idx(section)
+        if tab is not None:
+            self.set_by_tab(tab)
+        self.window.ui.dialogs.open('config.' + id, width=self.width, height=self.height)
+        self.editor.init(id)
+        self.window.core.settings.active[id] = True
+        self.window.controller.layout.restore_settings()
+
+        # update menu
+        self.update()
+
     def toggle_editor(self, id: str):
         """
-        Toggle settings
+        Toggle settings dialog
 
         :param id: settings id
         """
@@ -71,11 +93,44 @@ class Settings:
 
             # if no API key, focus on API key input
             if self.window.core.config.get('api_key') is None or self.window.core.config.get('api_key') == '':
-                self.window.ui.config_option['api_key'].setFocus()
+                self.window.ui.config['config']['api_key'].setFocus()
+
+            self.window.controller.layout.restore_settings()  # restore previous selected settings tab
 
         # update menu
         self.update()
 
+    def set_by_tab(self, idx: int):
+        """
+        Set current section by tab index
+
+        :param idx: tab index
+        """
+        section_idx = 0
+        for section_id in self.editor.get_sections():
+            if section_idx == idx:
+                break
+            section_idx += 1
+        current = self.window.ui.models['settings.section.list'].index(idx, 0)
+        self.window.ui.nodes['settings.section.list'].setCurrentIndex(current)
+        self.window.ui.tabs['settings.section'].setCurrentIndex(idx)
+
+    def get_tab_idx(self, section_id: str) -> int:
+        """
+        Get section tab index
+
+        :param section_id: plugin id
+        :return: tab index
+        """
+        section_idx = None
+        i = 0
+        for id in self.editor.get_sections():
+            if id == section_id:
+                section_idx = i
+                break
+            i += 1
+        return section_idx
+
     def toggle_file_editor(self, file: str = None):
         """
         Toggle file editor
@@ -125,11 +180,12 @@ class Settings:
     def open_config_dir(self):
         """Open user config directory"""
         if os.path.exists(self.window.core.config.path):
-            self.window.controller.files.open_dir(self.window.core.config.path, True)
+            self.window.controller.files.open_dir(self.window.core.config.path)
         else:
             self.window.ui.status('Config directory not exists: {}'.format(self.window.core.config.path))
 
     def welcome_settings(self):
-        """Open settings at first launch (no API key)"""
-        self.toggle_editor('settings')
+        """Open settings at first launch (if no API key yet)"""
+        self.open_section("general")
+        self.window.ui.config['config']['api_key'].setFocus()
         self.window.ui.dialogs.close('info.start')
