@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.30 21:00:00                  #
+# Updated Date: 2024.01.23 23:00:00                  #
 # ================================================== #
 
 import copy
@@ -17,15 +17,24 @@ from pygpt_net.utils import trans
 class Editor:
     def __init__(self, window=None):
         """
-        Settings controller
+        Settings editor controller
 
         :param window: Window instance
         """
         self.window = window
         self.options = {}
+        self.sections = {}
         self.before_config = {}
         self.initialized = False
 
+    def setup(self):
+        """Set up plugin settings"""
+        idx = None
+        # restore previous selected or restored tab on dialog create
+        if 'settings.section' in self.window.ui.tabs:
+            idx = self.window.ui.tabs['settings.section'].currentIndex()
+        self.window.settings.setup(idx)  # widget dialog Plugins
+
     def init(self, id: str):
         """
         Initialize settings
@@ -43,6 +52,11 @@ class Editor:
         self.window.ui.add_hook("update.config.vision.capture.auto", self.hook_update)
         self.window.ui.add_hook("update.config.ctx.records.limit", self.hook_update)
         self.window.ui.add_hook("update.config.layout.density", self.hook_update)
+        self.window.ui.add_hook("update.config.layout.tooltips", self.hook_update)
+        self.window.ui.add_hook("update.config.img_dialog_open", self.hook_update)
+        self.window.ui.add_hook("update.config.debug", self.hook_update)
+        # self.window.ui.add_hook("llama.idx.storage", self.hook_update)  # vector store update
+        # self.window.ui.add_hook("update.config.llama.idx.list", self.hook_update)
 
         if id == 'settings':
             options = {}
@@ -67,6 +81,7 @@ class Editor:
         :param initialize: True if marks settings as initialized
         """
         self.options = self.window.core.settings.get_options()
+        self.sections = self.window.core.settings.get_sections()
         if initialize:
             self.initialized = True
 
@@ -97,16 +112,35 @@ class Editor:
         self.window.controller.ui.update_font_size()
         self.window.controller.ui.update()
 
+        self.window.core.idx.sync_items()
+        self.window.controller.idx.update()
+
         # update layout if needed
         if self.before_config['layout.density'] != self.window.core.config.get('layout.density'):
             self.window.controller.theme.reload()
 
+        # update dirs if needed
+        if self.before_config['upload.data_dir'] != self.window.core.config.get('upload.data_dir'):
+            self.window.core.camera.install()
+            self.window.core.image.install()
+            self.window.core.filesystem.install()
+            self.window.controller.files.update_explorer()
+
+        # update file explorer if vector store provider changed
+        self.window.controller.idx.indexer.update_explorer()
+
         self.before_config = copy.deepcopy(self.window.core.config.all())
         self.window.controller.settings.close_window(id)
 
     def hook_update(self, key, value, caller, *args, **kwargs):
         """
         Hook: on settings update
+
+        :param key: config key
+        :param value: config value
+        :param caller: caller name
+        :param args: args
+        :param kwargs: kwargs
         """
         if self.window.core.config.get(key) == value:
             return
@@ -119,18 +153,25 @@ class Editor:
         # update markdown
         elif key == "theme.markdown":
             self.window.core.config.set(key, value)
-            self.window.controller.theme.update_markdown(force=True)
+            self.window.controller.theme.markdown.update(force=True)
+
+        # update layout tooltips
+        elif key == "layout.tooltips":
+            self.window.core.config.set(key, value)
+            self.window.controller.theme.common.toggle_tooltips()
 
         # update raw output
         elif key == "render.plain":
             self.window.core.config.set(key, value)
             if not value:
                 self.window.controller.ctx.refresh()
-                self.window.controller.theme.update_markdown(force=True)
+                self.window.controller.theme.markdown.update(force=True)
                 self.window.ui.nodes['output.raw'].setChecked(False)
             else:
-                self.window.controller.theme.clear_markdown()
+                self.window.controller.theme.markdown.clear()
                 self.window.ui.nodes['output.raw'].setChecked(True)
+            # restore previous font size
+            self.window.controller.ui.update_font_size()
 
         # call vision checkboxes events
         elif key == "vision.capture.enabled":
@@ -147,9 +188,20 @@ class Editor:
             self.window.controller.ctx.update(True, False)
 
         # update layout density
-        elif key == 'layout.density' and caller == "slider":
+        elif key == "layout.density" and caller == "slider":
             self.window.core.config.set(key, value)
             self.window.controller.theme.reload()
+            self.window.controller.theme.menu.update_density()
+
+        # toggle image dialog auto-open
+        elif key == "img_dialog_open":
+            self.window.core.config.set(key, value)
+            self.window.ui.nodes['dialog.image.open.toggle'].setChecked(value)
+
+        # debug: menu
+        elif key == "debug":
+            self.window.core.config.set(key, value)
+            self.window.ui.menu['menu.debug'].menuAction().setVisible(value)
 
     def toggle_collapsed(self, id: str, value: any, section: str):
         """
@@ -171,7 +223,8 @@ class Editor:
         :param force: force load
         """
         if not force:
-            self.window.ui.dialogs.confirm('settings.defaults.user', -1, trans('settings.defaults.user.confirm'))
+            self.window.ui.dialogs.confirm('settings.defaults.user', -1,
+                                           trans('settings.defaults.user.confirm'))
             return
 
         # load default user config
@@ -188,7 +241,8 @@ class Editor:
         :param force: force load
         """
         if not force:
-            self.window.ui.dialogs.confirm('settings.defaults.app', -1, trans('settings.defaults.app.confirm'))
+            self.window.ui.dialogs.confirm('settings.defaults.app', -1,
+                                           trans('settings.defaults.app.confirm'))
             return
 
         # load default user config
@@ -198,37 +252,37 @@ class Editor:
         self.init('settings')
         self.window.ui.dialogs.alert(trans('dialog.settings.defaults.app.result'))
 
-    def delete_item(self, parent_object, id: str, force: bool = False):
+    def get_sections(self) -> dict:
         """
-        Load delete item (from dict list) confirmation dialog or executes delete
+        Return settings sections dict
 
-        :param parent_object: parent object
-        :param id: item id
-        :param force: force delete
+        :return: dict sections dict
         """
-        if not force:
-            self.window.ui.dialogs.confirm('settings.dict.delete', id, trans('settings.dict.delete.confirm'),
-                                           parent_object)
-            return
+        return self.sections
 
-        # delete item
-        if parent_object is not None:
-            parent_object.delete_item_execute(id)
-
-    def get_options(self) -> dict:
+    def get_options(self, section: str = None) -> dict:
         """
         Return settings options dict
 
-        :return: dict Options dict
+        :param section: section ID
+        :return: dict options dict
         """
-        return self.options
+        if section is None:
+            return self.options
+        else:
+            options = {}
+            for key in self.options:
+                if 'section' in self.options[key] \
+                        and self.options[key]['section'] == section:
+                    options[key] = self.options[key]
+            return options
 
     def get_option(self, key: str) -> dict:
         """
         Return settings option
 
         :param key: option key
-        :return: dict Option dict
+        :return: dict option dict
         """
         if key not in self.options:
             return {}
