@@ -6,12 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.27 16:00:00                  #
 # ================================================== #
 
 from pygpt_net.item.assistant import AssistantItem
 from pygpt_net.item.attachment import AttachmentItem
-from pygpt_net.provider.assistant.json_file import JsonFileProvider
+from pygpt_net.provider.core.assistant.json_file import JsonFileProvider
 
 
 class Assistants:
@@ -30,9 +30,14 @@ class Assistants:
         """Install provider data"""
         self.provider.install()
 
-    def patch(self, app_version):
-        """Patch provider data"""
-        self.provider.patch(app_version)
+    def patch(self, app_version) -> bool:
+        """
+        Patch provider data
+
+        :param app_version: app version
+        :return: True if data was patched
+        """
+        return self.provider.patch(app_version)
 
     def get_by_idx(self, idx: int) -> str:
         """
