@@ -6,11 +6,15 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.30 19:00:00                  #
 # ================================================== #
 
+import copy
+
+from packaging.version import Version
+
 from pygpt_net.item.attachment import AttachmentItem
-from pygpt_net.provider.attachment.json_file import JsonFileProvider
+from pygpt_net.provider.core.attachment.json_file import JsonFileProvider
 
 
 class Attachments:
@@ -29,9 +33,14 @@ class Attachments:
         """Install provider data"""
         self.provider.install()
 
-    def patch(self, app_version: str):
-        """Patch provider data"""
-        self.provider.patch(app_version)
+    def patch(self, app_version: Version) -> bool:
+        """
+        Patch provider data
+
+        :param app_version: app version
+        :return: True if data was patched
+        """
+        return self.provider.patch(app_version)
 
     def select(self, mode: str, id: str):
         """
@@ -48,7 +57,7 @@ class Attachments:
 
     def count(self, mode: str) -> int:
         """
-        Count attachments
+        Count attachments in mode
 
         :param mode: mode
         :return: attachments count
@@ -60,7 +69,7 @@ class Attachments:
 
     def get_ids(self, mode: str) -> list:
         """
-        Get items IDs
+        Get items IDs in mode
 
         :param mode: mode
         :return: items UUIDs
@@ -72,7 +81,7 @@ class Attachments:
 
     def get_id_by_idx(self, mode: str, idx: int) -> str | None:
         """
-        Get ID by index
+        Get ID by index in mode
 
         :param mode: mode
         :param idx: index
@@ -86,7 +95,7 @@ class Attachments:
 
     def get_by_id(self, mode: str, id: str) -> AttachmentItem | None:
         """
-        Return attachment by ID
+        Return attachment by ID in mode
 
         :param mode: mode
         :param id: file id
@@ -100,7 +109,7 @@ class Attachments:
 
     def get_by_idx(self, mode: str, index: int) -> AttachmentItem | None:
         """
-        Return item by index
+        Return item by index in mode
 
         :param mode: mode
         :param index: item index
@@ -122,7 +131,13 @@ class Attachments:
 
         return self.items[mode]
 
-    def new(self, mode: str, name: str = None, path: str = None, auto_save: bool = True) -> AttachmentItem:
+    def new(
+            self,
+            mode: str,
+            name: str = None,
+            path: str = None,
+            auto_save: bool = True
+    ) -> AttachmentItem:
         """
         Create new attachment
 
@@ -132,6 +147,11 @@ class Attachments:
         :param auto_save: auto_save
         :return: AttachmentItem
         """
+        # make local copy of external attachment if enabled
+        if self.window.core.config.get("upload.store"):
+            if not self.window.core.filesystem.in_work_dir(path):
+                path = self.window.core.filesystem.store_upload(path)
+
         attachment = self.create()
         attachment.name = name
         attachment.path = path
@@ -197,35 +217,52 @@ class Attachments:
 
         return len(self.items[mode]) > 0
 
-    def delete(self, mode: str, id: str):
+    def delete(self, mode: str, id: str, remove_local: bool = False):
         """
         Delete attachment by file_id
 
         :param mode: mode
         :param id: file id
+        :param remove_local: remove local copy
         """
         if mode not in self.items:
             self.items[mode] = {}
 
         if id in self.items[mode]:
+            if remove_local:
+                self.window.core.filesystem.remove_upload(
+                    self.items[mode][id].path,
+                )
             del self.items[mode][id]
             self.save()
 
-    def delete_all(self, mode: str):
+    def delete_all(self, mode: str, remove_local: bool = False):
         """
         Delete all attachments
 
         :param mode: mode
+        :param remove_local: remove local copy
         """
-        self.clear(mode)
+        self.clear(
+            mode,
+            remove_local=remove_local,
+        )
         self.provider.truncate(mode)
 
-    def clear(self, mode: str):
+    def clear(self, mode: str, remove_local: bool = False):
         """
         Clear all attachments in mode
 
         :param mode: mode
+        :param remove_local: remove local copy
         """
+        if mode not in self.items:
+            self.items[mode] = {}
+        if remove_local:
+            for id in self.items[mode]:
+                self.window.core.filesystem.remove_upload(
+                    self.items[mode][id].path,
+                )
         self.items[mode] = {}
 
     def clear_all(self):
@@ -234,7 +271,12 @@ class Attachments:
         """
         self.items = {}
 
-    def replace_id(self, mode: str, tmp_id: str, attachment: AttachmentItem):
+    def replace_id(
+            self,
+            mode: str,
+            tmp_id: str,
+            attachment: AttachmentItem
+    ):
         """
         Replace temporary id with real one
 
@@ -274,7 +316,7 @@ class Attachments:
             attachment = attachments[id]
             result[id] = {
                 'name': attachment.name,
-                'path': attachment.path
+                'path': attachment.path,
             }
         return result
 
@@ -291,9 +333,11 @@ class Attachments:
             item = AttachmentItem()
             item.name = id
 
-            if 'name' in file and file['name'] is not None and file['name'] != "":
+            if 'name' in file \
+                    and file['name'] is not None and file['name'] != "":
                 item.name = file['name']
-            if 'path' in file and file['path'] is not None and file['path'] != "":
+            if 'path' in file \
+                    and file['path'] is not None and file['path'] != "":
                 item.path = file['path']
 
             item.id = id
@@ -316,7 +360,24 @@ class Attachments:
     def load(self):
         """Load attachments"""
         self.items = self.provider.load()
+        # replace workdir placeholder with current workdir
+        for mode in self.items:
+            for id in self.items[mode]:
+                attachment = self.items[mode][id]
+                if attachment.path is not None:
+                    attachment.path = self.window.core.filesystem.to_workdir(
+                        attachment.path,
+                    )
 
     def save(self):
         """Save attachments"""
-        self.provider.save(self.items)
+        # replace current workdir with placeholder
+        data = copy.deepcopy(self.items)  # copy to avoid changing original data
+        for mode in data:
+            for id in data[mode]:
+                attachment = data[mode][id]
+                if attachment.path is not None:
+                    attachment.path = self.window.core.filesystem.make_local(
+                        attachment.path,
+                    )
+        self.provider.save(data)
