@@ -6,14 +6,15 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.30 17:00:00                  #
 # ================================================== #
 
 import datetime
-import os
+
+from packaging.version import Version
 
 from pygpt_net.item.ctx import CtxItem, CtxMeta
-from pygpt_net.provider.ctx.db_sqlite import DbSqliteProvider
+from pygpt_net.provider.core.ctx.db_sqlite import DbSqliteProvider
 from pygpt_net.utils import trans
 
 
@@ -40,22 +41,28 @@ class Ctx:
         self.last_model = None
         self.search_string = None
         self.allowed_modes = {
-            'chat': ['chat', 'completion', 'img', 'langchain', 'vision', 'assistant'],
-            'completion': ['chat', 'completion', 'img', 'langchain', 'vision', 'assistant'],
-            'img': ['img'],
-            'langchain': ['chat', 'completion', 'img', 'langchain', 'vision', 'assistant'],
-            'vision': ['chat', 'completion', 'img', 'langchain', 'vision', 'assistant'],
-            'assistant': ['assistant'],
-            'llama_index': ['llama_index'],
+            'chat': ["chat", "completion", "img", "langchain", "vision", "assistant", "llama_index", "agent"],
+            'completion': ["chat", "completion", "img", "langchain", "vision", "assistant", "llama_index", "agent"],
+            'img': ["img"],
+            'langchain': ["chat", "completion", "img", "langchain", "vision", "assistant", "llama_index", "agent"],
+            'vision': ["chat", "completion", "img", "langchain", "vision", "assistant", "llama_index", "agent"],
+            'assistant': ["assistant"],
+            'llama_index': ["chat", "completion", "img", "langchain", "vision", "assistant", "llama_index", "agent"],
+            'agent': ["chat", "completion", "img", "langchain", "vision", "assistant", "llama_index", "agent"],
         }
 
     def install(self):
         """Install provider data"""
         self.provider.install()
 
-    def patch(self, app_version: str):
-        """Patch provider data"""
-        self.provider.patch(app_version)
+    def patch(self, app_version: Version) -> bool:
+        """
+        Patch provider data
+
+        :param app_version: app version
+        :return: True if data was patched
+        """
+        return self.provider.patch(app_version)
 
     def select(self, id: int):
         """
@@ -79,9 +86,11 @@ class Ctx:
             self.preset = ctx.preset
 
             # restore model if exists in current mode
-            if ctx.last_model is not None and self.window.core.models.has_model(self.mode, ctx.last_model):
+            if ctx.last_model is not None \
+                    and self.window.core.models.has_model(self.mode, ctx.last_model):
                 self.model = ctx.last_model
-            elif ctx.model is not None and self.window.core.models.has_model(self.mode, ctx.model):
+            elif ctx.model is not None \
+                    and self.window.core.models.has_model(self.mode, ctx.model):
                 self.model = ctx.model
 
             self.items = self.load(id)
@@ -362,15 +371,6 @@ class Ctx:
         # remove all ctx data in provider
         self.provider.truncate()
 
-        # delete all txt history files from history dir
-        path = os.path.join(self.window.core.config.path, 'history')
-        for file in os.listdir(path):
-            if file.endswith('.txt'):
-                try:
-                    os.remove(os.path.join(path, file))
-                except Exception as e:
-                    self.window.core.debug.log(e)
-
     def clear(self):
         """Clear ctx items"""
         self.items = []
@@ -414,7 +414,13 @@ class Ctx:
             self.meta[self.current].status = self.status
             self.save(self.current)
 
-    def count_prompt_items(self, model: str, mode: str, used_tokens: int = 100, max_tokens: int = 1000) -> (int, int):
+    def count_prompt_items(
+            self,
+            model: str,
+            mode: str,
+            used_tokens: int = 100,
+            max_tokens: int = 1000
+    ) -> (int, int):
         """
         Count ctx items to add to prompt
 
@@ -439,8 +445,14 @@ class Ctx:
 
         return i, context_tokens
 
-    def get_prompt_items(self, model: str, mode: str = "chat", used_tokens: int = 100, max_tokens: int = 1000,
-                         ignore_first: bool = True) -> list:
+    def get_prompt_items(
+            self,
+            model: str,
+            mode: str = "chat",
+            used_tokens: int = 100,
+            max_tokens: int = 1000,
+            ignore_first: bool = True
+    ) -> list:
         """
         Return ctx items to add to prompt
 
@@ -533,6 +545,23 @@ class Ctx:
         if len(self.items) > 0:
             self.items.pop()
 
+    def duplicate(self, id: int) -> int:
+        """
+        Duplicate ctx
+
+        :param id: ctx id
+        :return: new ctx id
+        """
+        if id in self.meta:
+            meta = self.create()
+            new_id = meta.id
+            old_data = self.meta[id].to_dict()
+            meta.from_dict(old_data)
+            meta.id = new_id
+            items = self.load(id)
+            self.provider.save_all(meta.id, meta, items)
+            return meta.id
+
     def remove_first(self):
         """Remove first item"""
         if len(self.items) > 0:
