@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.23 19:00:00                  #
 # ================================================== #
 
 import os
@@ -20,9 +20,7 @@ from pygpt_net.migrations import Migrations
 
 class Database:
     def __init__(self, window=None):
-        """
-        Database provider core
-        """
+        """Database provider core"""
         self.window = window
         self.db_path = None
         self.db_name = 'db.sqlite'
@@ -32,26 +30,24 @@ class Database:
         self.migrations = Migrations()
 
     def init(self):
-        """
-        Initialize database
-        """
+        """Initialize database"""
         if not self.initialized:
             self.db_path = os.path.join(self.window.core.config.path, self.db_name)
             self.prepare()
 
     def prepare(self):
-        """
-        Prepare database
-        """
-        self.engine = create_engine('sqlite:///{}'.format(self.db_path), echo=self.echo, future=True)
+        """Prepare database"""
+        self.engine = create_engine(
+            'sqlite:///{}'.format(self.db_path),
+            echo=self.echo,
+            future=True
+        )
         if not self.is_installed():
             self.install()
         self.initialized = True
 
     def install(self):
-        """
-        Install database schema
-        """
+        """Install database schema"""
         with self.engine.begin() as conn:
             conn.execute(text("""
             CREATE TABLE IF NOT EXISTS config (
@@ -124,9 +120,7 @@ class Database:
         return has_migrations
 
     def make_backup(self):
-        """
-        Make backup of database before migration
-        """
+        """Make backup of database before migration"""
         try:
             backup_path = os.path.join(self.window.core.config.path, 'db.sqlite.backup')
             if os.path.exists(backup_path):
@@ -136,9 +130,7 @@ class Database:
             print("[DB] Error while making backup of database: {}".format(e))
 
     def migrate(self):
-        """
-        Apply all DB migrations
-        """
+        """Apply all DB migrations"""
         db_version = self.get_version()
         migrations = Migrations().get_versions()
         sorted_migrations = sorted(migrations, key=lambda m: m.__class__.__name__)
@@ -200,5 +192,3 @@ class Database:
             """).bindparams(key=key, value=value, created_ts=ts, updated_ts=ts)
 
         conn.execute(stmt)
-
-
