@@ -6,9 +6,8 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.05 22:00:00                  #
+# Updated Date: 2023.12.28 21:00:00                  #
 # ================================================== #
-import os
 
 
 class AttachmentsDebug:
@@ -23,23 +22,22 @@ class AttachmentsDebug:
 
     def update(self):
         """Update debug window."""
-        self.window.app.debug.begin(self.id)
-
-        path = os.path.join(self.window.config.path, '', self.window.app.attachments.config_file)
-        self.window.app.debug.add(self.id, 'File', path)
+        self.window.core.debug.begin(self.id)
 
         modes = ['chat', 'completion', 'img', 'vision', 'langchain', 'assistant']
         for mode in modes:
-            self.window.app.debug.add(self.id, '[mode]', mode)
-            attachments = self.window.app.attachments.get_all(mode)
+            self.window.core.debug.add(self.id, '[mode]', mode)
+            attachments = self.window.core.attachments.get_all(mode)
             for key in list(attachments):
                 prefix = "[{}] ".format(key)
                 attachment = attachments[key]
-                self.window.app.debug.add(self.id, prefix + 'ID', str(key))
-                self.window.app.debug.add(self.id, 'id', str(attachment.id))
-                self.window.app.debug.add(self.id, 'name', str(attachment.name))
-                self.window.app.debug.add(self.id, 'path', str(attachment.path))
-                self.window.app.debug.add(self.id, 'remote', str(attachment.remote))
-                self.window.app.debug.add(self.id, 'send', str(attachment.send))
+                self.window.core.debug.add(self.id, '----', '')
+                self.window.core.debug.add(self.id, str(key), '')
+                self.window.core.debug.add(self.id, prefix + 'ID', str(key))
+                self.window.core.debug.add(self.id, 'id', str(attachment.id))
+                self.window.core.debug.add(self.id, 'name', str(attachment.name))
+                self.window.core.debug.add(self.id, 'path', str(attachment.path))
+                self.window.core.debug.add(self.id, 'remote', str(attachment.remote))
+                self.window.core.debug.add(self.id, 'send', str(attachment.send))
 
-        self.window.app.debug.end(self.id)
+        self.window.core.debug.end(self.id)
