@@ -9,7 +9,7 @@
 # Updated Date: 2023.12.31 04:00:00                  #
 # ================================================== #
 
-from pygpt_net.provider.mode.json_file import JsonFileProvider
+from pygpt_net.provider.core.mode.json_file import JsonFileProvider
 
 
 class Modes:
