@@ -6,13 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.23 19:00:00                  #
 # ================================================== #
 
 import platform
 import os
 
 from PySide6 import QtCore, QtWidgets
+from PySide6.QtSvg import QSvgRenderer
 
 from pygpt_net.config import Config
 
@@ -26,7 +27,6 @@ class Platforms:
         :param window: Window instance
         """
         self.window = window
-        self.snap_name = 'pygpt'
 
     @staticmethod
     def prepare():
@@ -70,7 +70,6 @@ class Platforms:
         Return OS name
 
         :return: OS name
-        :rtype: str
         """
         return platform.system()
 
@@ -79,7 +78,6 @@ class Platforms:
         Return platform architecture
 
         :return: platform architecture
-        :rtype: str
         """
         return platform.machine()
 
@@ -88,7 +86,6 @@ class Platforms:
         Return True if OS is Linux
 
         :return: True if OS is Linux
-        :rtype: bool
         """
         return self.get_os() == 'Linux'
 
@@ -97,7 +94,6 @@ class Platforms:
         Return True if OS is MacOS
 
         :return: True if OS is MacOS
-        :rtype: bool
         """
         return self.get_os() == 'Darwin'
 
@@ -106,7 +102,6 @@ class Platforms:
         Return True if OS is Windows
 
         :return: True if OS is Windows
-        :rtype: bool
         """
         return self.get_os() == 'Windows'
 
@@ -115,8 +110,33 @@ class Platforms:
         Return True if app is running as snap
 
         :return: True if app is running as snap
-        :rtype: bool
         """
         return "SNAP" in os.environ \
                and "SNAP_NAME" in os.environ \
-               and os.environ["SNAP_NAME"] == self.snap_name
+               and os.environ["SNAP_NAME"] == Config.SNAP_NAME
+
+    def get_as_string(self) -> str:
+        """
+        Return platform as string
+
+        :return: platform as string
+        """
+        extra = ''
+        if self.is_snap():
+            extra = ' (snap)'
+        elif self.window.core.config.is_compiled():
+            extra = ' (standalone)'
+        return self.get_os() + ', ' + self.get_architecture() + extra
+
+    def is_svg_supported(self) -> bool:
+        """Check if SVG is supported"""
+        try:
+            data = """
+            <svg height="100" width="100">
+              <circle cx="50" cy="50" r="40" stroke="black" stroke-width="3" fill="red" />
+            </svg>
+            """
+            renderer = QSvgRenderer(data.encode('utf-8'))
+            return renderer.isValid()
+        except Exception as e:
+            return False
