@@ -6,14 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.30 17:00:00                  #
 # ================================================== #
 
 import copy
 
 from packaging.version import Version
 from pygpt_net.item.preset import PresetItem
-from pygpt_net.provider.preset.json_file import JsonFileProvider
+from pygpt_net.provider.core.preset.json_file import JsonFileProvider
 
 
 class Presets:
@@ -36,12 +36,11 @@ class Presets:
         """Patch provider data"""
         self.provider.patch(app_version)
 
-    def build(self):
+    def build(self) -> PresetItem:
         """
         Build empty preset
 
         :return: empty preset
-        :rtype: PresetItem
         """
         return PresetItem()
 
@@ -54,6 +53,8 @@ class Presets:
         curr_vision = self.build()
         curr_langchain = self.build()
         curr_assistant = self.build()
+        curr_llama = self.build()
+        curr_agent = self.build()
 
         # prepare ids
         id_chat = 'current.chat'
@@ -62,6 +63,8 @@ class Presets:
         id_vision = 'current.vision'
         id_langchain = 'current.langchain'
         id_assistant = 'current.assistant'
+        id_llama = 'current.llama_index'
+        id_agent = 'current.agent'
 
         # set default initial prompt for chat mode
         curr_chat.prompt = self.window.core.config.get('default_prompt')
@@ -79,6 +82,10 @@ class Presets:
             curr_langchain = self.items[id_langchain]
         if id_assistant in self.items:
             curr_assistant = self.items[id_assistant]
+        if id_llama in self.items:
+            curr_llama = self.items[id_llama]
+        if id_agent in self.items:
+            curr_agent = self.items[id_agent]
 
         # allow usage in specific mode
         curr_chat.chat = True
@@ -87,6 +94,8 @@ class Presets:
         curr_vision.vision = True
         curr_langchain.langchain = True
         curr_assistant.assistant = True
+        curr_llama.llama_index = True
+        curr_agent.agent = True
 
         # always apply default name
         curr_chat.name = '*'
@@ -95,6 +104,8 @@ class Presets:
         curr_vision.name = '*'
         curr_langchain.name = '*'
         curr_assistant.name = '*'
+        curr_llama.name = '*'
+        curr_agent.name = '*'
 
         # append at first position
         self.items = {
@@ -104,6 +115,8 @@ class Presets:
             id_vision: curr_vision,
             id_langchain: curr_langchain,
             id_assistant: curr_assistant,
+            id_llama: curr_llama,
+            id_agent: curr_agent,
             **self.items
         }
 
@@ -112,13 +125,13 @@ class Presets:
         Check if preset exists
 
         :param id: preset id
-        :return: bool
+        :return: True if exists
         """
         if id in self.items:
             return True
         return False
 
-    def get_first_mode(self, id: str) -> str:
+    def get_first_mode(self, id: str) -> str or None:
         """
         Return first mode for preset
 
@@ -138,6 +151,10 @@ class Presets:
             return 'langchain'
         if preset.assistant:
             return 'assistant'
+        if preset.llama_index:
+            return 'llama_index'
+        if preset.agent:
+            return 'agent'
         return None
 
     def has(self, mode: str, id: str) -> bool:
@@ -145,8 +162,8 @@ class Presets:
         Check if preset for mode exists
 
         :param mode: mode name
-        :param name: preset id
-        :return: bool
+        :param id : preset id
+        :return: True if exists
         """
         presets = self.get_by_mode(mode)
         if id in presets:
@@ -178,7 +195,9 @@ class Presets:
                     or (mode == 'img' and self.items[id].img) \
                     or (mode == 'vision' and self.items[id].vision) \
                     or (mode == 'langchain' and self.items[id].langchain) \
-                    or (mode == 'assistant' and self.items[id].assistant):
+                    or (mode == 'assistant' and self.items[id].assistant) \
+                    or (mode == 'llama_index' and self.items[id].llama_index) \
+                    or (mode == 'agent' and self.items[id].agent):
                 presets[id] = self.items[id]
         return presets
 
@@ -257,7 +276,12 @@ class Presets:
         """
         Sort presets by name
         """
-        self.items = dict(sorted(self.items.items(), key=lambda item: item[1].name))
+        self.items = dict(
+            sorted(
+                self.items.items(),
+                key=lambda item: item[1].name
+            )
+        )
 
     def get_all(self) -> dict:
         """
