@@ -6,9 +6,11 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.27 15:00:00                  #
 # ================================================== #
 
+import json
+
 from pygpt_net.item.attachment import AttachmentItem
 
 
@@ -168,3 +170,20 @@ class AssistantItem:
         Clear attachments
         """
         self.attachments = {}
+
+    def dump(self):
+        """
+        Dump item to string
+
+        :return: serialized item
+        :rtype: str
+        """
+        try:
+            return json.dumps(self.to_dict())
+        except Exception as e:
+            pass
+        return ""
+
+    def __str__(self):
+        """To string"""
+        return self.dump()
