@@ -6,10 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.27 21:00:00                  #
+# Updated Date: 2024.01.07 04:00:00                  #
 # ================================================== #
 
 from .Version20231227152900 import Version20231227152900  # 2.0.59
+from .Version20231230095000 import Version20231230095000  # 2.0.66
+from .Version20231231230000 import Version20231231230000  # 2.0.71
+from .Version20240106060000 import Version20240106060000  # 2.0.84
+from .Version20240107060000 import Version20240107060000  # 2.0.88
 
 
 class Migrations:
@@ -17,13 +21,16 @@ class Migrations:
         pass
 
     @staticmethod
-    def get_versions():
+    def get_versions() -> list:
         """
         Return migrations
 
         :return: list with migrations classes
-        :rtype: list
         """
         return [
             Version20231227152900(),  # 2.0.59
-        ]
\ No newline at end of file
+            Version20231230095000(),  # 2.0.66
+            Version20231231230000(),  # 2.0.71
+            Version20240106060000(),  # 2.0.84
+            Version20240107060000(),  # 2.0.88
+        ]
