@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.30 13:00:00                  #
 # ================================================== #
 
 import mimetypes
@@ -38,7 +38,8 @@ class Worker(BaseWorker):
         msg = None
         for item in self.cmds:
             try:
-                if item["cmd"] in self.plugin.allowed_cmds and self.plugin.is_cmd_allowed(item["cmd"]):
+                if item["cmd"] in self.plugin.allowed_cmds \
+                        and self.plugin.is_cmd_allowed(item["cmd"]):
                     request = {"cmd": item["cmd"]}  # prepare request item for result
 
                     # save file
@@ -46,16 +47,23 @@ class Worker(BaseWorker):
                         try:
                             msg = "Saving file: {}".format(item["params"]['filename'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                item["params"]['filename'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['filename'],
+                            )
                             data = item["params"]['data']
                             with open(path, 'w', encoding="utf-8") as file:
                                 file.write(data)
-                                file.close()
-                                response = {"request": request, "result": "OK"}
+                                response = {
+                                    "request": request,
+                                    "result": "OK",
+                                }
                                 self.log("File saved: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -65,16 +73,23 @@ class Worker(BaseWorker):
                         try:
                             msg = "Appending file: {}".format(item["params"]['filename'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                item["params"]['filename'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['filename'],
+                            )
                             data = item["params"]['data']
                             with open(path, 'a', encoding="utf-8") as file:
                                 file.write(data)
-                                file.close()
-                                response = {"request": request, "result": "OK"}
+                                response = {
+                                    "request": request,
+                                    "result": "OK",
+                                }
                                 self.log("File appended: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -84,19 +99,29 @@ class Worker(BaseWorker):
                         try:
                             msg = "Reading file: {}".format(item["params"]['filename'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                item["params"]['filename'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['filename'],
+                            )
                             if os.path.exists(path):
                                 with open(path, 'r', encoding="utf-8") as file:
                                     data = file.read()
-                                    response = {"request": request, "result": data}
-                                    file.close()
+                                    response = {
+                                        "request": request,
+                                        "result": data,
+                                    }
                                     self.log("File read: {}".format(path))
                             else:
-                                response = {"request": request, "result": "File not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "File not found",
+                                }
                                 self.log("File not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -106,17 +131,25 @@ class Worker(BaseWorker):
                         try:
                             msg = "Deleting file: {}".format(item["params"]['filename'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                item["params"]['filename'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['filename'],
+                            )
                             if os.path.exists(path):
                                 os.remove(path)
                                 response = {"request": request, "result": "OK"}
                                 self.log("File deleted: {}".format(path))
                             else:
-                                response = {"request": request, "result": "File not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "File not found",
+                                }
                                 self.log("File not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -126,18 +159,29 @@ class Worker(BaseWorker):
                         try:
                             msg = "Listing directory: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if os.path.exists(path):
                                 files = os.listdir(path)
-                                response = {"request": request, "result": files}
+                                response = {
+                                    "request": request,
+                                    "result": files,
+                                }
                                 self.log("Files listed: {}".format(path))
                                 self.log("Result: {}".format(files))
                             else:
-                                response = {"request": request, "result": "Directory not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "Directory not found",
+                                }
                                 self.log("Directory not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -147,17 +191,28 @@ class Worker(BaseWorker):
                         try:
                             msg = "Creating directory: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if not os.path.exists(path):
                                 os.makedirs(path)
-                                response = {"request": request, "result": "OK"}
+                                response = {
+                                    "request": request,
+                                    "result": "OK",
+                                }
                                 self.log("Directory created: {}".format(path))
                             else:
-                                response = {"request": request, "result": "Directory already exists"}
+                                response = {
+                                    "request": request,
+                                    "result": "Directory already exists",
+                                }
                                 self.log("Directory already exists: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -167,17 +222,28 @@ class Worker(BaseWorker):
                         try:
                             msg = "Deleting directory: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if os.path.exists(path):
                                 shutil.rmtree(path)
-                                response = {"request": request, "result": "OK"}
+                                response = {
+                                    "request": request,
+                                    "result": "OK",
+                                }
                                 self.log("Directory deleted: {}".format(path))
                             else:
-                                response = {"request": request, "result": "Directory not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "Directory not found",
+                                }
                                 self.log("Directory not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -185,8 +251,10 @@ class Worker(BaseWorker):
                     # download
                     elif item["cmd"] == "download_file" and self.plugin.is_cmd_allowed("download_file"):
                         try:
-                            dst = os.path.join(self.plugin.window.core.config.path, 'output',
-                                               item["params"]['dst'])
+                            dst = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['dst'],
+                            )
                             msg = "Downloading file: {} into {}".format(item["params"]['src'], dst)
                             self.log(msg)
 
@@ -196,27 +264,39 @@ class Worker(BaseWorker):
                                 # Download file from URL
                                 req = Request(
                                     url=src,
-                                    headers={'User-Agent': 'Mozilla/5.0'}
+                                    headers={'User-Agent': 'Mozilla/5.0'},
                                 )
                                 context = ssl.create_default_context()
                                 context.check_hostname = False
                                 context.verify_mode = ssl.CERT_NONE
-                                with urlopen(req, context=context, timeout=4) as response, open(dst, 'wb') as out_file:
+                                with urlopen(
+                                        req,
+                                        context=context,
+                                        timeout=4) as response, \
+                                        open(dst, 'wb') as out_file:
                                     shutil.copyfileobj(response, out_file)
                             else:
                                 # Handle local file paths
-                                src = os.path.join(self.plugin.window.core.config.path, 'output',
-                                                   item["params"]['src'])
+                                src = os.path.join(
+                                    self.plugin.window.core.config.get_user_dir('data'),
+                                    item["params"]['src'],
+                                )
 
                                 # Copy local file
                                 with open(src, 'rb') as in_file, open(dst, 'wb') as out_file:
                                     shutil.copyfileobj(in_file, out_file)
 
                             # handle result
-                            response = {"request": request, "result": "OK"}
+                            response = {
+                                "request": request,
+                                "result": "OK",
+                            }
                             self.log("File downloaded: {} into {}".format(src, dst))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -226,15 +306,25 @@ class Worker(BaseWorker):
                         try:
                             msg = "Copying file: {} into {}".format(item["params"]['src'], item["params"]['dst'])
                             self.log(msg)
-                            dst = os.path.join(self.plugin.window.core.config.path, 'output',
-                                               item["params"]['dst'])
-                            src = os.path.join(self.plugin.window.core.config.path, 'output',
-                                               item["params"]['src'])
+                            dst = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['dst'],
+                            )
+                            src = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['src'],
+                            )
                             shutil.copyfile(src, dst)
-                            response = {"request": request, "result": "OK"}
+                            response = {
+                                "request": request,
+                                "result": "OK",
+                            }
                             self.log("File copied: {} into {}".format(src, dst))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -245,15 +335,25 @@ class Worker(BaseWorker):
                             msg = "Copying directory: {} into {}".format(item["params"]['src'],
                                                                          item["params"]['dst'])
                             self.log(msg)
-                            dst = os.path.join(self.plugin.window.core.config.path, 'output',
-                                               item["params"]['dst'])
-                            src = os.path.join(self.plugin.window.core.config.path, 'output',
-                                               item["params"]['src'])
+                            dst = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['dst'],
+                            )
+                            src = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['src'],
+                            )
                             shutil.copytree(src, dst)
-                            response = {"request": request, "result": "OK"}
+                            response = {
+                                "request": request,
+                                "result": "OK",
+                            }
                             self.log("Directory copied: {} into {}".format(src, dst))
                         except Exception as e:
-                            response = {"request": request, "result": "Error {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -263,13 +363,25 @@ class Worker(BaseWorker):
                         try:
                             msg = "Moving: {} into {}".format(item["params"]['src'], item["params"]['dst'])
                             self.log(msg)
-                            dst = os.path.join(self.plugin.window.core.config.path, 'output', item["params"]['dst'])
-                            src = os.path.join(self.plugin.window.core.config.path, 'output', item["params"]['src'])
+                            dst = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['dst'],
+                            )
+                            src = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['src'],
+                            )
                             shutil.move(src, dst)
-                            response = {"request": request, "result": "OK"}
+                            response = {
+                                "request": request,
+                                "result": "OK",
+                            }
                             self.log("Moved: {} into {}".format(src, dst))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -279,15 +391,24 @@ class Worker(BaseWorker):
                         try:
                             msg = "Checking if directory exists: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output', item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if os.path.isdir(path):
-                                response = {"request": request, "result": "OK"}
+                                response = {
+                                    "request": request,
+                                    "result": "OK",
+                                }
                                 self.log("Directory exists: {}".format(path))
                             else:
                                 response = {"request": request, "result": "Directory not found"}
                                 self.log("Directory not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -297,15 +418,27 @@ class Worker(BaseWorker):
                         try:
                             msg = "Checking if file exists: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output', item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if os.path.isfile(path):
-                                response = {"request": request, "result": "OK"}
+                                response = {
+                                    "request": request,
+                                    "result": "OK",
+                                }
                                 self.log("File exists: {}".format(path))
                             else:
-                                response = {"request": request, "result": "File not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "File not found",
+                                }
                                 self.log("File not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -315,15 +448,27 @@ class Worker(BaseWorker):
                         try:
                             msg = "Checking if path exists: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output', item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if os.path.exists(path):
-                                response = {"request": request, "result": "OK"}
+                                response = {
+                                    "request": request,
+                                    "result": "OK",
+                                }
                                 self.log("Path exists: {}".format(path))
                             else:
-                                response = {"request": request, "result": "File or directory not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "File or directory not found",
+                                }
                                 self.log("Path not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -333,15 +478,27 @@ class Worker(BaseWorker):
                         try:
                             msg = "Checking file size: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output', item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if os.path.exists(path):
-                                response = {"request": request, "result": os.path.getsize(path)}
+                                response = {
+                                    "request": request,
+                                    "result": os.path.getsize(path),
+                                }
                                 self.log("File size: {}".format(os.path.getsize(path)))
                             else:
-                                response = {"request": request, "result": "File not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "File not found",
+                                }
                                 self.log("File not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
@@ -351,7 +508,10 @@ class Worker(BaseWorker):
                         try:
                             msg = "Checking file info: {}".format(item["params"]['path'])
                             self.log(msg)
-                            path = os.path.join(self.plugin.window.core.config.path, 'output', item["params"]['path'])
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
                             if os.path.exists(path):
                                 data = {
                                     "size": os.path.getsize(path),
@@ -365,22 +525,72 @@ class Worker(BaseWorker):
                                     "is_mount": os.path.ismount(path),
                                     'stat': os.stat(path),
                                 }
-                                response = {"request": request, "result": data}
+                                response = {
+                                    "request": request,
+                                    "result": data,
+                                }
                                 self.log("File info: {}".format(data))
                             else:
-                                response = {"request": request, "result": "File not found"}
+                                response = {
+                                    "request": request,
+                                    "result": "File not found",
+                                }
                                 self.log("File not found: {}".format(path))
                         except Exception as e:
-                            response = {"request": request, "result": "Error: {}".format(e)}
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
+                            self.error(e)
+                            self.log("Error: {}".format(e))
+                        self.response(response)
+
+                    # get file as attachment
+                    elif item["cmd"] == "get_file" and self.plugin.is_cmd_allowed("get_file"):
+                        try:
+                            msg = "Adding attachment: {}".format(item["params"]['path'])
+                            self.log(msg)
+                            path = os.path.join(
+                                self.plugin.window.core.config.get_user_dir('data'),
+                                item["params"]['path'],
+                            )
+
+                            if os.path.exists(path):
+                                # make attachment
+                                mode = self.plugin.window.core.config.get('mode')
+                                title = os.path.basename(path)
+                                self.plugin.window.core.attachments.new(mode, title, path, False)
+                                self.plugin.window.core.attachments.save()
+                                self.plugin.window.controller.attachment.update()
+                                response = {
+                                    "request": request,
+                                    "result": "Sending attachment: {}".format(title),
+                                }
+                                self.log("Added attachment: {}".format(path))
+                            else:
+                                response = {
+                                    "request": request,
+                                    "result": "File not found",
+                                }
+                                self.log("File not found: {}".format(path))
+                        except Exception as e:
+                            response = {
+                                "request": request,
+                                "result": "Error: {}".format(e),
+                            }
                             self.error(e)
                             self.log("Error: {}".format(e))
                         self.response(response)
 
             except Exception as e:
-                self.response({"request": item, "result": "Error: {}".format(e)})
+                self.response(
+                    {
+                        "request": item,
+                        "result": "Error: {}".format(e),
+                    }
+                )
                 self.error(e)
                 self.log("Error: {}".format(e))
 
         if msg is not None:
-            self.log(msg)
             self.status(msg)
