@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.10 10:00:00                  #
+# Updated Date: 2024.01.19 18:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
@@ -16,7 +16,7 @@ from PySide6.QtWidgets import QPushButton, QHBoxLayout, QLabel, QVBoxLayout, QSc
 from pygpt_net.plugin.base import BasePlugin
 from pygpt_net.ui.widget.dialog.settings_plugin import PluginSettingsDialog
 from pygpt_net.ui.widget.element.group import CollapsedGroup
-from pygpt_net.ui.widget.element.url import UrlLabel
+from pygpt_net.ui.widget.element.labels import UrlLabel
 from pygpt_net.ui.widget.lists.plugin import PluginList
 from pygpt_net.ui.widget.option.checkbox import OptionCheckbox
 from pygpt_net.ui.widget.option.combo import OptionCombo
@@ -36,6 +36,7 @@ class Plugins:
         """
         self.window = window
         self.dialog_id = "plugin_settings"
+        self.max_list_width = 250
 
     def setup(self, idx=None):
         """
@@ -173,7 +174,7 @@ class Plugins:
         self.update_list(id, data)
 
         # set max width to list
-        self.window.ui.nodes[id].setMaximumWidth(250)
+        self.window.ui.nodes[id].setMaximumWidth(self.max_list_width)
 
         main_layout = QHBoxLayout()
         main_layout.addWidget(self.window.ui.nodes[id])
@@ -194,6 +195,8 @@ class Plugins:
                 self.window.controller.plugins.set_by_tab(idx)
             except Exception as e:
                 print('Failed restore plugin settings tab: {}'.format(idx))
+        else:
+            self.window.controller.plugins.set_by_tab(0)
 
     def build_widgets(self, plugin: BasePlugin, options: dict) -> dict:
         """
@@ -373,10 +376,8 @@ class Plugins:
         i = 0
         for n in data:
             self.window.ui.models[id].insertRow(i)
-            name = data[n].name
-            # translate if localization is enabled
-            if data[n].use_locale:
-                domain = 'plugin.' + data[n].id
-                name = trans('plugin.name', False, domain)
+            name = self.window.core.plugins.get_name(data[n].id)
+            tooltip = self.window.core.plugins.get_desc(data[n].id)
             self.window.ui.models[id].setData(self.window.ui.models[id].index(i, 0), name)
+            self.window.ui.models[id].setData(self.window.ui.models[id].index(i, 0), tooltip, Qt.ToolTipRole)
             i += 1
