@@ -6,17 +6,19 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.09 17:00:00                  #
+# Updated Date: 2024.01.27 19:00:00                  #
 # ================================================== #
 
 from pygpt_net.ui.dialog.about import About
 from pygpt_net.ui.dialog.assistant import Assistant
 from pygpt_net.ui.dialog.changelog import Changelog
+from pygpt_net.ui.dialog.create import Create
 from pygpt_net.ui.dialog.debug import Debug
 from pygpt_net.ui.dialog.dictionary import Dictionary
 from pygpt_net.ui.dialog.editor import Editor
 from pygpt_net.ui.dialog.image import Image
 from pygpt_net.ui.dialog.logger import Logger
+from pygpt_net.ui.dialog.models import Models
 from pygpt_net.ui.dialog.plugins import Plugins
 from pygpt_net.ui.dialog.preset import Preset
 from pygpt_net.ui.dialog.rename import Rename
@@ -38,6 +40,7 @@ class Dialogs:
         self.about = About(self.window)
         self.assistant = Assistant(self.window)
         self.changelog = Changelog(self.window)
+        self.create = Create(self.window)
         self.debug = Debug(self.window)
         self.dictionary = Dictionary(self.window)
         self.editor = Editor(self.window)
@@ -45,7 +48,6 @@ class Dialogs:
         self.logger = Logger(self.window)
         self.preset = Preset(self.window)
         self.rename = Rename(self.window)
-        self.settings = Settings(self.window)
         self.start = Start(self.window)
         self.update = Update(self.window)
 
@@ -56,7 +58,7 @@ class Dialogs:
 
         self.about.setup()
         self.changelog.setup()
-        self.settings.setup()
+        self.create.setup()
         self.preset.setup()
         self.assistant.setup()
         self.editor.setup()
@@ -66,7 +68,9 @@ class Dialogs:
         self.image.setup()
         self.logger.setup()
 
+        self.window.settings = Settings(self.window)
         self.window.plugin_settings = Plugins(self.window)
+        self.window.model_settings = Models(self.window)
         self.window.ui.dialog['alert'] = AlertDialog(self.window)
         self.window.ui.dialog['confirm'] = ConfirmDialog(self.window)
 
@@ -74,7 +78,13 @@ class Dialogs:
         """Post setup dialogs (after plugins and rest of data is registered)"""
         self.dictionary.setup()
 
-    def confirm(self, type, id, msg, parent_object=None):
+    def confirm(
+            self,
+            type,
+            id,
+            msg,
+            parent_object=None
+    ):
         """
         Show confirm dialog
 
@@ -113,7 +123,15 @@ class Dialogs:
         self.window.ui.dialog[id].data_id = data_id
         self.window.ui.dialog[id].show()
 
-    def open_dictionary_editor(self, id: str, option: dict, data: dict, idx: int, width=400, height=400):
+    def open_dictionary_editor(
+            self,
+            id: str,
+            option: dict,
+            data: dict,
+            idx: int,
+            width=400,
+            height=400
+    ):
         """
         Open dictionary editor dialog
 
@@ -134,7 +152,12 @@ class Dialogs:
         self.window.ui.dialog[dialog_id].idx = idx  # store editing record idx
         self.window.ui.dialog[dialog_id].show()
 
-    def register_dictionary(self, key: str, parent: str, option: dict):
+    def register_dictionary(
+            self,
+            key: str,
+            parent: str,
+            option: dict
+    ):
         """
         Register dictionary data to dictionary editor
 
@@ -145,7 +168,12 @@ class Dialogs:
         dict_id = parent + "." + key
         self.dictionary.register(dict_id, key, parent, option)
 
-    def open(self, id, width=400, height=400):
+    def open(
+            self,
+            id,
+            width=400,
+            height=400
+    ):
         """
         Open debug/config dialog
 
