@@ -6,12 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2024.01.28 22:00:00                  #
 # ================================================== #
 
 from PySide6.QtGui import QStandardItemModel, Qt
 from PySide6.QtWidgets import QVBoxLayout, QPushButton, QHBoxLayout, QCheckBox, QWidget
 
+from pygpt_net.ui.widget.element.labels import HelpLabel
 from pygpt_net.ui.widget.lists.attachment import AttachmentList
 from pygpt_net.utils import trans
 
@@ -42,9 +43,13 @@ class Attachments:
         buttons.addWidget(self.setup_send_clear())
         buttons.addWidget(self.setup_capture_clear())
 
+        self.window.ui.nodes['tip.input.attachments'] = HelpLabel(trans('tip.input.attachments'), self.window)
+
         # layout
         layout = QVBoxLayout()
+        layout.addWidget(self.window.ui.nodes['tip.input.attachments'])
         layout.addWidget(self.window.ui.nodes['attachments'])
+
         layout.addLayout(buttons)
 
         return layout
@@ -91,7 +96,7 @@ class Attachments:
         self.window.ui.nodes['attachments.btn.add'].clicked.connect(
             lambda: self.window.controller.attachment.open_add())
         self.window.ui.nodes['attachments.btn.clear'].clicked.connect(
-            lambda: self.window.controller.attachment.clear())
+            lambda: self.window.controller.attachment.clear(remove_local=True))
 
         self.window.ui.nodes['attachments.send_clear'] = QCheckBox(trans('attachments.send_clear'))
         self.window.ui.nodes['attachments.send_clear'].stateChanged.connect(
