@@ -6,19 +6,22 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.30 02:00:00                  #
+# Updated Date: 2024.01.27 11:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
-from PySide6.QtWidgets import QVBoxLayout, QLabel, QHBoxLayout, QPushButton, QRadioButton, QCheckBox, \
-    QTabWidget, QWidget
+from PySide6.QtGui import QIcon
+from PySide6.QtWidgets import QVBoxLayout, QLabel, QHBoxLayout, QPushButton, QRadioButton, QCheckBox, QWidget
 
 from pygpt_net.ui.layout.chat.attachments import Attachments
 from pygpt_net.ui.layout.chat.attachments_uploaded import AttachmentsUploaded
 from pygpt_net.ui.layout.status import Status
 from pygpt_net.ui.widget.audio.input import AudioInput
+from pygpt_net.ui.widget.element.labels import HelpLabel
+from pygpt_net.ui.widget.tabs.Input import InputTabs
 from pygpt_net.ui.widget.textarea.input import ChatInput
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
 
 
 class Input:
@@ -49,13 +52,17 @@ class Input:
         files_uploaded = self.setup_attachments_uploaded()
 
         # tabs
-        self.window.ui.tabs['input'] = QTabWidget()
+        self.window.ui.tabs['input'] = InputTabs(self.window)
         self.window.ui.tabs['input'].setMinimumHeight(self.min_height_input_tab)
         self.window.ui.tabs['input'].addTab(input, trans('input.tab'))
         self.window.ui.tabs['input'].addTab(files, trans('attachments.tab'))
         self.window.ui.tabs['input'].addTab(files_uploaded, trans('attachments_uploaded.tab'))
         self.window.ui.tabs['input'].currentChanged.connect(self.update_min_height)  # update min height on tab change
 
+        self.window.ui.tabs['input'].setTabIcon(0, QIcon(":/icons/input.svg"))
+        self.window.ui.tabs['input'].setTabIcon(1, QIcon(":/icons/attachment.svg"))
+        self.window.ui.tabs['input'].setTabIcon(2, QIcon(":/icons/upload.svg"))
+
         # layout
         layout = QVBoxLayout()
         layout.addLayout(self.setup_header())
@@ -122,10 +129,8 @@ class Input:
         :return: QHBoxLayout
         """
         # header (input label + input counter)
-        self.window.ui.nodes['input.label'] = QLabel(trans("input.label"))
-        self.window.ui.nodes['input.label'].setStyleSheet(self.window.controller.theme.get_style('text_faded'))
+        self.window.ui.nodes['input.label'] = HelpLabel(trans("input.label"))
         self.window.ui.nodes['input.counter'] = QLabel("")
-        self.window.ui.nodes['input.counter'].setStyleSheet(self.window.controller.theme.get_style('text_faded'))
         self.window.ui.nodes['input.counter'].setToolTip(trans('tip.tokens.input'))
 
         # plugin audio input addon
