@@ -6,23 +6,26 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.11 09:00:00                  #
+# Updated Date: 2024.01.27 11:00:00                  #
 # ================================================== #
 
 import os
 
 from PySide6.QtCore import Qt
+from PySide6.QtGui import QIcon
 from PySide6.QtWidgets import QVBoxLayout, QLabel, QHBoxLayout, QCheckBox, QWidget, QSizePolicy
 
 from pygpt_net.ui.layout.chat.input import Input
 from pygpt_net.ui.layout.chat.calendar import Calendar
 from pygpt_net.ui.layout.chat.painter import Painter
 from pygpt_net.ui.widget.audio.output import AudioOutput
+from pygpt_net.ui.widget.element.labels import ChatStatusLabel
 from pygpt_net.ui.widget.tabs.output import OutputTabs
 from pygpt_net.ui.widget.textarea.output import ChatOutput
-from pygpt_net.ui.widget.textarea.notepad import NotepadOutput
+from pygpt_net.ui.widget.textarea.notepad import NotepadWidget
 from pygpt_net.ui.widget.filesystem.explorer import FileExplorer
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
 
 
 class Output:
@@ -48,17 +51,17 @@ class Output:
         self.window.ui.nodes['output'] = ChatOutput(self.window)
 
         # index status data
-        index_data = self.window.core.idx.get_idx_data()
+        index_data = self.window.core.idx.get_idx_data()  # get all idx data
 
         # file explorer
-        path = os.path.join(self.window.core.config.path, 'output')
+        path = self.window.core.config.get_user_dir('data')
         self.window.ui.nodes['output_files'] = FileExplorer(self.window, path, index_data)
 
         # notepads
         num_notepads = self.window.controller.notepad.get_num_notepads()
         if num_notepads > 0:
             for i in range(1, num_notepads + 1):
-                self.window.ui.notepad[i] = NotepadOutput(self.window)
+                self.window.ui.notepad[i] = NotepadWidget(self.window)
                 self.window.ui.notepad[i].id = i
 
         # tabs
@@ -77,11 +80,20 @@ class Output:
         # append notepads
         if num_notepads > 0:
             for i in range(1, num_notepads + 1):
-                self.window.ui.tabs['output'].addTab(self.window.ui.notepad[i],
-                                                     trans('output.tab.notepad') + " " + str(i))
+                tab = i + (self.window.controller.notepad.start_tab_idx - 1)
+                title = trans('output.tab.notepad')
+                if num_notepads > 1:
+                    title += " " + str(i)
+                self.window.ui.tabs['output'].addTab(self.window.ui.notepad[i], title)
+                self.window.ui.tabs['output'].setTabIcon(tab, QIcon(":/icons/paste.svg"))
 
         self.window.ui.tabs['output'].currentChanged.connect(self.window.controller.ui.output_tab_changed)
 
+        self.window.ui.tabs['output'].setTabIcon(0, QIcon(":/icons/chat.svg"))
+        self.window.ui.tabs['output'].setTabIcon(1, QIcon(":/icons/folder_filled.svg"))
+        self.window.ui.tabs['output'].setTabIcon(2, QIcon(":/icons/schedule.svg"))
+        self.window.ui.tabs['output'].setTabIcon(3, QIcon(":/icons/brush.svg"))
+
         layout = QVBoxLayout()
         layout.addWidget(self.window.ui.tabs['output'])
         layout.addLayout(self.setup_bottom())
@@ -98,19 +110,15 @@ class Output:
         :return: QHBoxLayout
         :rtype: QHBoxLayout
         """
-        self.window.ui.nodes['chat.label'] = QLabel("")
-        self.window.ui.nodes['chat.label'].setAlignment(Qt.AlignRight)
-        self.window.ui.nodes['chat.label'].setStyleSheet(self.window.controller.theme.get_style('text_faded'))
+        self.window.ui.nodes['chat.label'] = ChatStatusLabel("")
         self.window.ui.nodes['chat.label'].setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
+        self.window.ui.nodes['chat.label'].setWordWrap(False)
 
-        self.window.ui.nodes['chat.model'] = QLabel("")
-        self.window.ui.nodes['chat.model'].setAlignment(Qt.AlignRight)
-        self.window.ui.nodes['chat.model'].setStyleSheet(self.window.controller.theme.get_style('text_faded'))
+        self.window.ui.nodes['chat.model'] = ChatStatusLabel("")
         self.window.ui.nodes['chat.model'].setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
+        self.window.ui.nodes['chat.model'].setWordWrap(False)
 
-        self.window.ui.nodes['chat.plugins'] = QLabel("")
-        self.window.ui.nodes['chat.plugins'].setAlignment(Qt.AlignRight)
-        self.window.ui.nodes['chat.plugins'].setStyleSheet(self.window.controller.theme.get_style('text_faded'))
+        self.window.ui.nodes['chat.plugins'] = ChatStatusLabel("")
         self.window.ui.nodes['chat.plugins'].setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
 
         # add timestamp checkbox
@@ -134,17 +142,13 @@ class Output:
         self.window.ui.nodes['inline.vision'].setContentsMargins(0, 0, 0, 0)
 
         # tokens info
-        self.window.ui.nodes['prompt.context'] = QLabel("")
-        self.window.ui.nodes['prompt.context'].setAlignment(Qt.AlignRight)
-        self.window.ui.nodes['prompt.context'].setStyleSheet(self.window.controller.theme.get_style('text_faded'))
+        self.window.ui.nodes['prompt.context'] = ChatStatusLabel("")
         self.window.ui.nodes['prompt.context'].setToolTip(trans('tip.tokens.ctx'))
         self.window.ui.nodes['prompt.context'].setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
 
         # plugin audio output addon
         self.window.ui.plugin_addon['audio.output'] = AudioOutput(self.window)
-        self.window.ui.plugin_addon['schedule'] = QLabel("")
-        self.window.ui.plugin_addon['schedule'].setAlignment(Qt.AlignRight)
-        self.window.ui.plugin_addon['schedule'].setStyleSheet(self.window.controller.theme.get_style('text_faded'))
+        self.window.ui.plugin_addon['schedule'] = ChatStatusLabel("")
 
         opts_layout = QHBoxLayout()
         # opts_layout.setSpacing(2)  #
@@ -169,4 +173,11 @@ class Output:
         layout.addWidget(self.window.ui.nodes['prompt.context'])
         layout.setContentsMargins(0, 0, 0, 0)
 
-        return layout
+        self.window.ui.nodes['chat.footer'] = QWidget()
+        self.window.ui.nodes['chat.footer'].setLayout(layout)
+
+        final_layout = QVBoxLayout()
+        final_layout.addWidget(self.window.ui.nodes['chat.footer'])
+        final_layout.setContentsMargins(0, 0, 0, 0)
+
+        return final_layout
