@@ -6,15 +6,15 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.29 21:00:00                  #
+# Updated Date: 2024.01.27 11:00:00                  #
 # ================================================== #
 
-from PySide6 import QtCore, QtGui
-from PySide6.QtCore import Qt
+from PySide6 import QtCore
 from PySide6.QtGui import QStandardItemModel
-from PySide6.QtWidgets import QVBoxLayout, QLabel, QPushButton, QWidget
+from PySide6.QtWidgets import QVBoxLayout, QPushButton, QWidget
 from datetime import datetime, timedelta
 
+from pygpt_net.ui.widget.element.labels import TitleLabel
 from pygpt_net.ui.widget.lists.context import ContextList
 from pygpt_net.utils import trans
 
@@ -41,8 +41,7 @@ class CtxList:
 
         self.window.ui.nodes[id] = ContextList(self.window, id)
         self.window.ui.nodes[id].selection_locked = self.window.controller.ctx.context_change_locked
-        self.window.ui.nodes['ctx.label'] = QLabel(trans("ctx.list.label"))
-        self.window.ui.nodes['ctx.label'].setStyleSheet(self.window.controller.theme.get_style('text_bold'))
+        self.window.ui.nodes['ctx.label'] = TitleLabel(trans("ctx.list.label"))
 
         layout = QVBoxLayout()
         layout.addWidget(self.window.ui.nodes['ctx.new'])
@@ -83,7 +82,11 @@ class CtxList:
             self.window.ui.models[id].insertRow(i)
             dt = self.convert_date(data[n].updated)
             date_time_str = datetime.fromtimestamp(data[n].updated).strftime("%Y-%m-%d %H:%M")
-            name = data[n].name + ' (' + dt + ')'
+            title = data[n].name
+            # truncate to max 40 chars
+            if len(title) > 80:
+                title = title[:80] + '...'
+            name = title.replace("\n", "") + ' (' + dt + ')'
             index = self.window.ui.models[id].index(i, 0)
             mode_str = ''
             if data[n].last_mode is not None:
@@ -120,7 +123,7 @@ class CtxList:
             return f"{weeks_ago} " + trans('dt.weeks')
         elif days_ago < 30:
             return f"{days_ago} " + trans('dt.days_ago')
-        elif days_ago >= 30 and days_ago < 32:
+        elif 30 <= days_ago < 32:
             return trans('dt.month')
         else:
             return date.strftime("%Y-%m-%d")
