@@ -6,13 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.29 21:00:00                  #
+# Updated Date: 2024.01.27 11:00:00                  #
 # ================================================== #
 
 from PySide6 import QtCore
 from PySide6.QtGui import QStandardItemModel, Qt
-from PySide6.QtWidgets import QVBoxLayout, QLabel, QHBoxLayout, QPushButton, QWidget
+from PySide6.QtWidgets import QVBoxLayout, QHBoxLayout, QPushButton, QWidget
 
+from pygpt_net.ui.widget.element.labels import HelpLabel, TitleLabel
 from pygpt_net.ui.widget.lists.assistant import AssistantList
 from pygpt_net.utils import trans
 
@@ -58,8 +59,7 @@ class Assistants:
             lambda: self.window.controller.assistant.import_api())
 
         # label
-        self.window.ui.nodes['assistants.label'] = QLabel(trans("toolbox.assistants.label"))
-        self.window.ui.nodes['assistants.label'].setStyleSheet(self.window.controller.theme.get_style('text_bold'))
+        self.window.ui.nodes['assistants.label'] = TitleLabel(trans("toolbox.assistants.label"))
 
         # header
         header = QHBoxLayout()
@@ -76,10 +76,13 @@ class Assistants:
         self.window.ui.nodes[self.id].selection_locked = self.window.controller.assistant.change_locked
         self.window.ui.nodes[self.id].setMinimumWidth(40)
 
+        self.window.ui.nodes['tip.toolbox.assistants'] = HelpLabel(trans('tip.toolbox.assistants'), self.window)
+
         # rows
         layout = QVBoxLayout()
         layout.addWidget(header_widget)
         layout.addWidget(self.window.ui.nodes[self.id])
+        layout.addWidget(self.window.ui.nodes['tip.toolbox.assistants'])
 
         # model
         self.window.ui.models[self.id] = self.create_model(self.window)
