@@ -6,12 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.30 02:00:00                  #
+# Updated Date: 2024.01.30 17:00:00                  #
 # ================================================== #
 
 from PySide6.QtGui import Qt
-from PySide6.QtWidgets import QVBoxLayout, QLabel, QHBoxLayout, QPushButton, QWidget, QCheckBox, QSizePolicy
+from PySide6.QtWidgets import QVBoxLayout, QHBoxLayout, QPushButton, QWidget, QCheckBox, QSizePolicy
 
+from pygpt_net.ui.widget.element.labels import HelpLabel, TitleLabel
 from pygpt_net.ui.widget.option.textarea import OptionTextarea
 from pygpt_net.utils import trans
 
@@ -37,8 +38,7 @@ class Prompt:
             lambda: self.window.controller.chat.common.toggle_cmd(self.window.ui.nodes['cmd.enabled'].isChecked()))
 
         # label
-        self.window.ui.nodes['toolbox.prompt.label'] = QLabel(trans("toolbox.prompt"))
-        self.window.ui.nodes['toolbox.prompt.label'].setStyleSheet(self.window.controller.theme.get_style('text_bold'))
+        self.window.ui.nodes['toolbox.prompt.label'] = TitleLabel(trans("toolbox.prompt"))
 
         # clear
         self.window.ui.nodes['preset.clear'] = QPushButton(trans('preset.clear'))
@@ -65,11 +65,16 @@ class Prompt:
         self.window.ui.nodes['preset.prompt'].real_time = True
         self.window.ui.nodes['preset.prompt'].update_ui = False
         self.window.ui.nodes['preset.prompt'].setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+        self.window.ui.nodes['preset.prompt'].textChanged.connect(
+            lambda: self.window.controller.ui.update_tokens())
+
+        self.window.ui.nodes['tip.toolbox.prompt'] = HelpLabel(trans('tip.toolbox.prompt'), self.window)
 
         # rows
         layout = QVBoxLayout()
         layout.addLayout(header)
         layout.addWidget(self.window.ui.nodes['preset.prompt'])
+        layout.addWidget(self.window.ui.nodes['tip.toolbox.prompt'])
         layout.setContentsMargins(0, 0, 0, 0)
 
         widget = QWidget()
