@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2024.01.29 14:00:00                  #
 # ================================================== #
 
 from PySide6.QtGui import QAction, QIcon, QResizeEvent
@@ -14,6 +14,7 @@ from PySide6.QtWidgets import QMenu
 
 from pygpt_net.ui.widget.lists.base import BaseList
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
 
 
 class AttachmentList(BaseList):
@@ -72,19 +73,19 @@ class AttachmentList(BaseList):
         :param event: context menu event
         """
         actions = {}
-        actions['open'] = QAction(QIcon.fromTheme("document-open"), trans('action.open'), self)
+        actions['open'] = QAction(QIcon(":/icons/view.svg"), trans('action.open'), self)
         actions['open'].triggered.connect(
             lambda: self.action_open(event))
 
-        actions['open_dir'] = QAction(QIcon.fromTheme("system-file-manager"), trans('action.open_dir'), self)
+        actions['open_dir'] = QAction(QIcon(":/icons/folder_filled.svg"), trans('action.open_dir'), self)
         actions['open_dir'].triggered.connect(
             lambda: self.action_open_dir(event))
 
-        actions['rename'] = QAction(QIcon.fromTheme("edit-edit"), trans('action.rename'), self)
+        actions['rename'] = QAction(QIcon(":/icons/edit.svg"), trans('action.rename'), self)
         actions['rename'].triggered.connect(
             lambda: self.action_rename(event))
 
-        actions['delete'] = QAction(QIcon.fromTheme("edit-delete"), trans('action.delete'), self)
+        actions['delete'] = QAction(QIcon(":/icons/delete.svg"), trans('action.delete'), self)
         actions['delete'].triggered.connect(
             lambda: self.action_delete(event))
 
