@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2024.01.29 23:00:00                  #
 # ================================================== #
 import os
 
@@ -16,6 +16,7 @@ from PySide6.QtWidgets import QMenu
 
 from pygpt_net.ui.widget.lists.base import BaseList
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
 
 
 class ContextList(BaseList):
@@ -59,16 +60,21 @@ class ContextList(BaseList):
         idx = item.row()
 
         actions = {}
-        actions['rename'] = QAction(QIcon.fromTheme("edit-edit"), trans('action.rename'), self)
+        actions['rename'] = QAction(QIcon(":/icons/edit.svg"), trans('action.rename'), self)
         actions['rename'].triggered.connect(
             lambda: self.action_rename(event))
 
-        actions['delete'] = QAction(QIcon.fromTheme("edit-delete"), trans('action.delete'), self)
+        actions['duplicate'] = QAction(QIcon(":/icons/copy.svg"), trans('action.duplicate'), self)
+        actions['duplicate'].triggered.connect(
+            lambda: self.action_duplicate(event))
+
+        actions['delete'] = QAction(QIcon(":/icons/delete.svg"), trans('action.delete'), self)
         actions['delete'].triggered.connect(
             lambda: self.action_delete(event))
 
         menu = QMenu(self)
         menu.addAction(actions['rename'])
+        menu.addAction(actions['duplicate'])
         menu.addAction(actions['delete'])
 
         # set label menu
@@ -78,14 +84,42 @@ class ContextList(BaseList):
             if status_id == 0:
                 name = '-'
             status_action = QAction(name, self)
+            if status_id == 0:
+                status_action.setIcon(QIcon(":/icons/close.svg"))
+            else:
+                status_action.setIcon(QIcon(":/icons/edit.svg"))
             status_action.triggered.connect(
                 lambda checked=False, s_id=status_id: self.window.controller.ctx.set_label(idx, s_id))
             set_label_menu.addAction(status_action)
 
+        idx_menu = QMenu(trans('action.idx'), self)
+
+        # indexes list
+        idxs = self.window.core.config.get('llama.idx.list')
+        if len(idxs) > 0:
+            for index in idxs:
+                id = index['id']
+                name = index['name'] + " (" + index['id'] + ")"
+                action = idx_menu.addAction("IDX: " + name)
+                action.setIcon(QIcon(":/icons/search.svg"))
+                action.triggered.connect(lambda checked=False, idx=idx, index=id:
+                                         self.action_idx(idx, index))
+
+            menu.addMenu(idx_menu)
+
         if idx >= 0:
             self.window.controller.ctx.select_by_idx(item.row())
             menu.exec_(event.globalPos())
 
+    def action_idx(self, ctx_idx, idx):
+        """
+        Index with llama context action handler
+
+        :param ctx_idx: row idx in context list
+        :param idx: index id
+        """
+        self.window.controller.idx.indexer.index_ctx_meta(ctx_idx, idx)
+
     def action_rename(self, event):
         """
         Rename action handler
@@ -97,6 +131,17 @@ class ContextList(BaseList):
         if idx >= 0:
             self.window.controller.ctx.rename(idx)
 
+    def action_duplicate(self, event):
+        """
+        Rename duplicate handler
+
+        :param event: mouse event
+        """
+        item = self.indexAt(event.pos())
+        idx = item.row()
+        if idx >= 0:
+            self.window.controller.ctx.common.duplicate_by_idx(idx)
+
     def action_important(self, event):
         """
         Set as important action handler
