@@ -13,21 +13,34 @@ from PySide6.QtWidgets import QTextEdit
 
 
 class OptionTextarea(QTextEdit):
-    def __init__(self, window=None, id=None, autoupdate=False, section=None):
+    def __init__(self, window=None, parent_id: str = None, id: str = None, option: dict = None):
         """
-        Settings input
+        Settings textarea
 
         :param window: main window
         :param id: option id
-        :param autoupdate: auto update
-        :param section: settings section
+        :param parent_id: parent option id
+        :param option: option data
         """
         super(OptionTextarea, self).__init__(window)
         self.window = window
         self.id = id
-        self.section = section
-        self.autoupdate = autoupdate
+        self.parent_id = parent_id
+        self.option = option
+        self.value = False
+        self.title = ""
+        self.real_time = False
         self.update_ui = True
+        self.setAcceptRichText(False)
+
+        # init from option data
+        if self.option is not None:
+            if "label" in self.option:
+                self.title = self.option["label"]
+            if "value" in self.option:
+                self.value = self.option["value"]
+            if "real_time" in self.option:
+                self.real_time = self.option["real_time"]
 
     def keyPressEvent(self, event):
         """
@@ -36,8 +49,8 @@ class OptionTextarea(QTextEdit):
         :param event: key event
         """
         super(OptionTextarea, self).keyPressEvent(event)
-        if not self.autoupdate:
+        if not self.real_time:
             return
-        self.window.controller.settings.editor.change(self.id, self.toPlainText(), self.section)
+        self.window.controller.config.input.on_update(self.parent_id, self.id, self.option, self.toPlainText())
         if self.update_ui:
             self.window.controller.ui.update()
