@@ -6,14 +6,16 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.06 06:00:00                  #
+# Updated Date: 2024.01.29 18:00:00                  #
 # ================================================== #
 
 from PySide6 import QtCore
 from PySide6.QtCore import Qt
+from PySide6.QtGui import QAction, QIcon
 from PySide6.QtWidgets import QTextEdit, QApplication, QMenu
 
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
 
 
 class ChatInput(QTextEdit):
@@ -30,14 +32,19 @@ class ChatInput(QTextEdit):
         self.value = self.window.core.config.data['font_size.input']
         self.max_font_size = 42
         self.min_font_size = 8
+        self.textChanged.connect(self.window.controller.ui.update_tokens)
 
     def contextMenuEvent(self, event):
         menu = self.createStandardContextMenu()
         selected_text = self.textCursor().selectedText()
         if selected_text:
+            # plain text
+            plain_text = self.textCursor().selection().toPlainText()
+
             # audio read
-            action = menu.addAction(trans('text.context_menu.audio.read'))
+            action = QAction(QIcon(":/icons/volume.svg"), trans('text.context_menu.audio.read'), self)
             action.triggered.connect(self.audio_read_selection)
+            menu.addAction(action)
 
             # copy to
             copy_to_menu = QMenu(trans('text.context_menu.copy_to'), self)
@@ -47,16 +54,31 @@ class ChatInput(QTextEdit):
             if num_notepads > 0:
                 for i in range(1, num_notepads + 1):
                     name = self.window.controller.notepad.get_notepad_name(i)
-                    action = copy_to_menu.addAction(name)
+                    action = QAction(QIcon(":/icons/paste.svg"), name, self)
                     action.triggered.connect(lambda checked=False, i=i:
                                              self.window.controller.notepad.append_text(selected_text, i))
+                    copy_to_menu.addAction(action)
 
             # calendar
-            action = copy_to_menu.addAction(trans('text.context_menu.copy_to.calendar'))
+            action = QAction(QIcon(":/icons/calendar.svg"), trans('text.context_menu.copy_to.calendar'), self)
             action.triggered.connect(
-                lambda: self.window.controller.calendar.append_text(selected_text))
+                lambda: self.window.controller.calendar.note.append_text(selected_text))
+            copy_to_menu.addAction(action)
 
             menu.addMenu(copy_to_menu)
+
+            # save as (selected)
+            action = QAction(QIcon(":/icons/save.svg"), trans('action.save_as'), self)
+            action.triggered.connect(
+                lambda: self.window.controller.chat.common.save_text(plain_text))
+            menu.addAction(action)
+        else:
+            # save as (all)
+            action = QAction(QIcon(":/icons/save.svg"), trans('action.save_as'), self)
+            action.triggered.connect(
+                lambda: self.window.controller.chat.common.save_text(self.toPlainText()))
+            menu.addAction(action)
+
         menu.exec_(event.globalPos())
 
     def audio_read_selection(self):
@@ -72,7 +94,6 @@ class ChatInput(QTextEdit):
         :param event: key event
         """
         super(ChatInput, self).keyPressEvent(event)
-        self.window.controller.ui.update_tokens()
         if event.key() in (QtCore.Qt.Key_Return, QtCore.Qt.Key_Enter):
             mode = self.window.core.config.get('send_mode')
             if mode > 0:  # Enter or Shift + Enter
