@@ -6,13 +6,42 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.07 08:00:00                  #
+# Updated Date: 2024.01.29 18:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
-from PySide6.QtWidgets import QTextEdit, QMenu
+from PySide6.QtGui import QAction, QIcon
+from PySide6.QtWidgets import QTextEdit, QMenu, QWidget, QVBoxLayout
 
+from pygpt_net.ui.widget.element.labels import HelpLabel
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
+
+
+class NotepadWidget(QWidget):
+    def __init__(self, window=None):
+        """
+        Notepad
+
+        :param window: main window
+        """
+        super(NotepadWidget, self).__init__(window)
+        self.window = window
+        self.id = 1
+        self.textarea = NotepadOutput(self.window)
+        self.window.ui.nodes['tip.output.tab.notepad'] = HelpLabel(trans('tip.output.tab.notepad'), self.window)
+
+        layout = QVBoxLayout()
+        layout.addWidget(self.textarea)
+        layout.addWidget(self.window.ui.nodes['tip.output.tab.notepad'])
+        layout.setContentsMargins(0, 0, 0, 0)
+        self.setLayout(layout)
+
+    def setText(self, text):
+        self.textarea.setText(text)
+
+    def toPlainText(self):
+        return self.textarea.toPlainText()
 
 
 class NotepadOutput(QTextEdit):
@@ -25,7 +54,7 @@ class NotepadOutput(QTextEdit):
         super(NotepadOutput, self).__init__(window)
         self.window = window
         self.setAcceptRichText(False)
-        self.setStyleSheet(self.window.controller.theme.get_style('chat_output'))
+        self.setStyleSheet(self.window.controller.theme.style('font.chat.output'))
         self.textChanged.connect(
             lambda: self.window.controller.notepad.save(self.id))
         self.value = self.window.core.config.data['font_size']
@@ -37,17 +66,22 @@ class NotepadOutput(QTextEdit):
         menu = self.createStandardContextMenu()
         selected_text = self.textCursor().selectedText()
         if selected_text:
+            # plain text
+            plain_text = self.textCursor().selection().toPlainText()
+
             # audio read
-            action = menu.addAction(trans('text.context_menu.audio.read'))
+            action = QAction(QIcon(":/icons/volume.svg"), trans('text.context_menu.audio.read'), self)
             action.triggered.connect(self.audio_read_selection)
+            menu.addAction(action)
 
             # copy to
             copy_to_menu = QMenu(trans('text.context_menu.copy_to'), self)
 
             # input
-            action = copy_to_menu.addAction(trans('text.context_menu.copy_to.input'))
+            action = QAction(QIcon(":/icons/input.svg"), trans('text.context_menu.copy_to.input'), self)
             action.triggered.connect(
-                lambda: self.window.controller.chat.render.append_text(selected_text))
+                lambda: self.window.controller.chat.common.append_to_input(selected_text))
+            copy_to_menu.addAction(action)
 
             # notepad
             num_notepads = self.window.controller.notepad.get_num_notepads()
@@ -56,16 +90,31 @@ class NotepadOutput(QTextEdit):
                     if i == self.id:
                         continue
                     name = self.window.controller.notepad.get_notepad_name(i)
-                    action = copy_to_menu.addAction(name)
+                    action = QAction(QIcon(":/icons/paste.svg"), name, self)
                     action.triggered.connect(lambda checked=False, i=i:
                                              self.window.controller.notepad.append_text(selected_text, i))
+                    copy_to_menu.addAction(action)
 
             # calendar
-            action = copy_to_menu.addAction(trans('text.context_menu.copy_to.calendar'))
+            action = QAction(QIcon(":/icons/calendar.svg"), trans('text.context_menu.copy_to.calendar'), self)
             action.triggered.connect(
-                lambda: self.window.controller.calendar.append_text(selected_text))
+                lambda: self.window.controller.calendar.note.append_text(selected_text))
+            copy_to_menu.addAction(action)
 
             menu.addMenu(copy_to_menu)
+
+            # save as (selected)
+            action = QAction(QIcon(":/icons/save.svg"), trans('action.save_as'), self)
+            action.triggered.connect(
+                lambda: self.window.controller.chat.common.save_text(plain_text))
+            menu.addAction(action)
+        else:
+            # save as (all)
+            action = QAction(QIcon(":/icons/save.svg"), trans('action.save_as'), self)
+            action.triggered.connect(
+                lambda: self.window.controller.chat.common.save_text(self.toPlainText()))
+            menu.addAction(action)
+
         menu.exec_(event.globalPos())
 
     def audio_read_selection(self):
