@@ -6,14 +6,15 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.01.06 06:00:00                  #
+# Updated Date: 2024.01.29 18:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
 from PySide6.QtWidgets import QTextBrowser, QMenu
-from PySide6.QtGui import QDesktopServices
+from PySide6.QtGui import QDesktopServices, QAction, QIcon
 
 from pygpt_net.utils import trans
+import pygpt_net.icons_rc
 
 
 class ChatOutput(QTextBrowser):
@@ -26,7 +27,7 @@ class ChatOutput(QTextBrowser):
         super(ChatOutput, self).__init__(window)
         self.window = window
         self.setReadOnly(True)
-        self.setStyleSheet(self.window.controller.theme.get_style('chat_output'))
+        self.setStyleSheet(self.window.controller.theme.style('font.chat.output'))
         self.value = self.window.core.config.data['font_size']
         self.max_font_size = 42
         self.min_font_size = 8
@@ -40,7 +41,12 @@ class ChatOutput(QTextBrowser):
 
         :param url: url
         """
-        QDesktopServices.openUrl(url)
+        # local file
+        if not url.scheme().startswith('http'):
+            self.window.controller.files.open(url.toLocalFile())
+        else:
+            # external link
+            QDesktopServices.openUrl(url)
 
     def contextMenuEvent(self, event):
         """
@@ -50,45 +56,65 @@ class ChatOutput(QTextBrowser):
         """
         menu = self.createStandardContextMenu()
         selected_text = self.textCursor().selectedText()
+
         if selected_text:
+            # plain text
+            plain_text = self.textCursor().selection().toPlainText()
+
             # audio read
-            action = menu.addAction(trans('text.context_menu.audio.read'))
+            action = QAction(QIcon(":/icons/volume.svg"), trans('text.context_menu.audio.read'), self)
             action.triggered.connect(self.audio_read_selection)
+            menu.addAction(action)
 
             # copy to
             copy_to_menu = QMenu(trans('text.context_menu.copy_to'), self)
 
             # input
-            action = copy_to_menu.addAction(trans('text.context_menu.copy_to.input'))
+            action = QAction(QIcon(":/icons/input.svg"), trans('text.context_menu.copy_to.input'), self)
             action.triggered.connect(
-                lambda: self.window.controller.chat.render.append_text(selected_text))
+                lambda: self.window.controller.chat.common.append_to_input(selected_text))
+            copy_to_menu.addAction(action)
 
             # notepad
             num_notepads = self.window.controller.notepad.get_num_notepads()
             if num_notepads > 0:
                 for i in range(1, num_notepads + 1):
                     name = self.window.controller.notepad.get_notepad_name(i)
-                    action = copy_to_menu.addAction(name)
+                    action = QAction(QIcon(":/icons/paste.svg"), name, self)
                     action.triggered.connect(lambda checked=False, i=i:
                                              self.window.controller.notepad.append_text(selected_text, i))
+                    copy_to_menu.addAction(action)
 
             # calendar
-            action = copy_to_menu.addAction(trans('text.context_menu.copy_to.calendar'))
+            action = QAction(QIcon(":/icons/calendar.svg"), trans('text.context_menu.copy_to.calendar'), self)
             action.triggered.connect(
-                lambda: self.window.controller.calendar.append_text(selected_text))
+                lambda: self.window.controller.calendar.note.append_text(selected_text))
+            copy_to_menu.addAction(action)
 
             menu.addMenu(copy_to_menu)
+
+            # save as (selected)
+            action = QAction(QIcon(":/icons/save.svg"), trans('action.save_as'), self)
+            action.triggered.connect(
+                lambda: self.window.controller.chat.common.save_text(plain_text))
+            menu.addAction(action)
+        else:
+            # save as (all)
+            action = QAction(QIcon(":/icons/save.svg"), trans('action.save_as'), self)
+            action.triggered.connect(
+                lambda: self.window.controller.chat.common.save_text(self.toPlainText()))
+            menu.addAction(action)
+
         menu.exec_(event.globalPos())
 
     def audio_read_selection(self):
-        """
-        Read selected text (audio)
-        """
+        """Read selected text (audio)"""
         self.window.controller.audio.read_text(self.textCursor().selectedText())
 
     def wheelEvent(self, event):
         """
         Wheel event: set font size
+
         :param event: Event
         """
         if event.modifiers() & Qt.ControlModifier:
