@@ -6,9 +6,10 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.31 04:00:00                  #
+# Updated Date: 2024.01.22 09:00:00                  #
 # ================================================== #
 
+import json
 import os
 import re
 from pygpt_net.core.locale import Locale
@@ -74,7 +75,8 @@ def get_init_value(key: str = "__version__") -> str:
 def get_app_meta() -> dict:
     """
     Return app meta data
-    :return: app meta data=
+
+    :return: app meta data
     """
     return {
         'github': get_init_value("__github__"),
@@ -87,3 +89,37 @@ def get_app_meta() -> dict:
         'author': get_init_value("__author__"),
         'email': get_init_value("__email__")
     }
+
+
+def parse_args(data: list) -> dict:
+    """
+    Parse keyword arguments from list of items
+
+    :param data: list of arguments items
+    :return: dict of parsed keyword arguments
+    """
+    args = {}
+    for item in data:
+        key = item['name']
+        value = item['value']
+        type = item['type']
+        if type == 'int':
+            args[key] = int(value)
+        elif type == 'float':
+            args[key] = float(value)
+        elif type == 'bool':
+            if str(value).lower() == 'true':
+                args[key] = True
+            elif str(value).lower() == 'false':
+                args[key] = False
+            else:
+                args[key] = bool(int(value))
+        elif type == 'dict':
+            args[key] = json.loads(value)
+        elif type == 'list':
+            args[key] = [x.strip() for x in value.split(',')]
+        elif type == 'None':
+            args[key] = None
+        else:
+            args[key] = str(value)
+    return args
